@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public
  * License along with this library; see the file COPYING.
  * If not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef _KFILE_TORRENT_H
 #define _KFILE_TORRENT_H
@@ -47,7 +47,7 @@ class KTorrentPlugin : public KFilePlugin
      * @param name the name of this object (not user-readable)
      * @param args unused by this class
      */
-    KTorrentPlugin (QObject *parent, const char *name, const QStringList &args);
+    KTorrentPlugin (QObject *parent, const QStringList &args);
 
     /**
      * Destructor that closes the dictionary holding the torrent information.
