@@ -3,7 +3,7 @@
    Copyright (C) 2002 by Patrick Charbonnier <pch@freeshell.org>
    Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
    Copyright (C) 2002 Carsten Pfeiffer <pfeiffer@kde.org>
-   Copyright (C) 2006, 2007 Urs Wolfer <uwolfer @ kde.org>
+   Copyright (C) 2006 - 2008 Urs Wolfer <uwolfer @ kde.org>
    Copyright (C) 2006 Dario Massarin <nekkar@libero.it>
    Copyright (C) 2008 Lukas Appelhans <l.appelhans@gmx.de>
 
@@ -63,6 +63,7 @@ MainWindow::MainWindow(bool showMainwindow, bool startWithoutAnimation, QWidget
     // do not quit the app when it has been minimized to system tray and a new transfer dialog
     // gets opened and closed again.
     qApp->setQuitOnLastWindowClosed(false);
+    setAttribute(Qt::WA_DeleteOnClose, false);
 
     // create the model
     KGet::self( this );
@@ -90,6 +91,9 @@ MainWindow::MainWindow(bool showMainwindow, bool startWithoutAnimation, QWidget
 
     //Some of the widgets are initialized in slotDelayedInit()
     QTimer::singleShot( 0, this, SLOT(slotDelayedInit()) );
+
+    // Update the title with the active transfers percent using the mainwindowmodelobserver
+    KGet::addObserver(new MainWindowModelObserver(this));
 }
 
 MainWindow::~MainWindow()
@@ -112,37 +116,80 @@ QSize MainWindow::sizeHint() const
     return QSize(720, 380);
 }
 
+int MainWindow::transfersPercent()
+{
+    int percent = 0;
+    int activeTransfers = 0;
+    foreach (const TransferHandler *handler, KGet::allTransfers()) {
+        if (handler->status() == Job::Running) {
+            activeTransfers ++;
+            percent += handler->percent();
+        }
+    }
+
+    if (activeTransfers > 0) {
+        return percent/activeTransfers;
+    }
+    else {
+        return -1;
+    }
+}
+
+void MainWindow::exportTransfers(bool plain)
+{
+    QString filter = "";
+    if (!plain) {
+        filter = "*.kgt|" + i18n("KGet Transfer List") + " (*.kgt)";
+    }
+
+    QString filename = KFileDialog::getSaveFileName
+        (KUrl(),
+         filter,
+         this,
+         i18n("Export Transfers")
+        );
+
+    if(!filename.isEmpty())
+        KGet::save(filename, plain);
+}
+
 void MainWindow::setupActions()
 {
-    QAction *newDownloadAction = actionCollection()->addAction("new_download");
+    KAction *newDownloadAction = actionCollection()->addAction("new_download");
     newDownloadAction->setText(i18n("&New Download..."));
     newDownloadAction->setIcon(KIcon("document-new"));
     newDownloadAction->setShortcuts(KShortcut("Ctrl+N"));
     connect(newDownloadAction, SIGNAL(triggered()), SLOT(slotNewTransfer()));
 
-    QAction *openAction = actionCollection()->addAction("import_transfers");
+    KAction *openAction = actionCollection()->addAction("import_transfers");
     openAction->setText(i18n("&Import Transfers..."));
     openAction->setIcon(KIcon("document-open"));
     openAction->setShortcuts(KShortcut("Ctrl+I"));
     connect(openAction, SIGNAL(triggered()), SLOT(slotImportTransfers()));
 
-    QAction *exportAction = actionCollection()->addAction("export_transfers");
+    KAction *exportAction = actionCollection()->addAction("export_transfers");
     exportAction->setText(i18n("&Export Transfers List..."));
     exportAction->setIcon(KIcon("document-export"));
     exportAction->setShortcuts(KShortcut("Ctrl+E"));
     connect(exportAction, SIGNAL(triggered()), SLOT(slotExportTransfers()));
 
-    QAction *deleteGroupAction = actionCollection()->addAction("delete_groups");
+    KAction *exportPlainAction = actionCollection()->addAction("export_plain_transfers");
+    exportPlainAction->setText(i18n("&Export Transfers as Plain Text"));
+    exportPlainAction->setIcon(KIcon("document-export"));
+    exportPlainAction->setShortcuts(KShortcut("Ctrl+P"));
+    connect(exportPlainAction, SIGNAL(triggered()), SLOT(slotExportPlainTransfers()));
+
+    KAction *deleteGroupAction = actionCollection()->addAction("delete_groups");
     deleteGroupAction->setText(i18n("Delete Group"));
     deleteGroupAction->setIcon(KIcon("edit-delete"));
     connect(deleteGroupAction, SIGNAL(triggered()), SLOT(slotDeleteGroup()));
 
-    QAction *renameGroupAction = actionCollection()->addAction("rename_groups");
+    KAction *renameGroupAction = actionCollection()->addAction("rename_groups");
     renameGroupAction->setText(i18n("Rename Group"));
     renameGroupAction->setIcon(KIcon("edit-rename"));
     connect(renameGroupAction, SIGNAL(triggered()), SLOT(slotRenameGroup()));
 
-    QAction *setIconGroupAction = actionCollection()->addAction("seticon_groups");
+    KAction *setIconGroupAction = actionCollection()->addAction("seticon_groups");
     setIconGroupAction->setText(i18n("Set Icon"));
     setIconGroupAction->setIcon(KIcon("preferences-desktop-icons"));
     connect(setIconGroupAction, SIGNAL(triggered()), SLOT(slotSetIconGroup()));
@@ -163,56 +210,51 @@ void MainWindow::setupActions()
     m_konquerorIntegration->setChecked(Settings::konquerorIntegration());
 
     // local - Destroys all sub-windows and exits
-    QAction *quitAction = KStandardAction::quit(this, SLOT(slotQuit()), actionCollection());
-    actionCollection()->addAction("quit", quitAction);
+    KStandardAction::quit(this, SLOT(slotQuit()), actionCollection());
     // local - Standard configure actions
-    QAction *preferencesAction = KStandardAction::preferences(this, SLOT(slotPreferences()), actionCollection());
-    actionCollection()->addAction("preferences", preferencesAction);
-    QAction *configToolbarAction = KStandardAction::configureToolbars(this, SLOT(slotConfigureToolbars()), actionCollection());
-    actionCollection()->addAction("configure_toolbars", configToolbarAction);
-    QAction *keyBindingsAction = KStandardAction::keyBindings(this, SLOT(slotConfigureKeys()), actionCollection());
-    actionCollection()->addAction("configure_keys", keyBindingsAction);
-    QAction *cinfigNotifyAction = KStandardAction::configureNotifications(this, SLOT(slotConfigureNotifications()), actionCollection());
-    actionCollection()->addAction("configure_notifications", cinfigNotifyAction);
+    KStandardAction::preferences(this, SLOT(slotPreferences()), actionCollection());
+    KStandardAction::configureToolbars(this, SLOT(slotConfigureToolbars()), actionCollection());
+    KStandardAction::keyBindings(this, SLOT(slotConfigureKeys()), actionCollection());
+
+    KStandardAction::configureNotifications(this, SLOT(slotConfigureNotifications()), actionCollection());
     m_menubarAction = KStandardAction::showMenubar(this, SLOT(slotShowMenubar()), actionCollection());
     m_menubarAction->setChecked(!menuBar()->isHidden());
-    actionCollection()->addAction("settings_showmenubar", m_menubarAction);
 
     // Transfer related actions
-    QAction *deleteSelectedAction = actionCollection()->addAction("delete_selected_download");
+    KAction *deleteSelectedAction = actionCollection()->addAction("delete_selected_download");
     deleteSelectedAction->setText(i18nc("delete selected transfer item", "Delete Selected"));
     deleteSelectedAction->setIcon(KIcon("edit-delete"));
     deleteSelectedAction->setShortcuts(KShortcut("Del"));
     connect(deleteSelectedAction, SIGNAL(triggered()), SLOT(slotDeleteSelected()));
 
-    QAction *deleteAllFinishedAction = actionCollection()->addAction("delete_all_finished");
+    KAction *deleteAllFinishedAction = actionCollection()->addAction("delete_all_finished");
     deleteAllFinishedAction->setText(i18nc("delete all finished transfers", "Delete all finished"));
     deleteAllFinishedAction->setIcon(KIcon("edit-clear-list"));
     connect(deleteAllFinishedAction, SIGNAL(triggered()), SLOT(slotDeleteFinished()));
 
-    QAction *redownloadSelectedAction = actionCollection()->addAction("redownload_selected_download");
+    KAction *redownloadSelectedAction = actionCollection()->addAction("redownload_selected_download");
     redownloadSelectedAction->setText(i18nc("redownload selected transfer item", "Redownload Selected"));
     redownloadSelectedAction->setIcon(KIcon("view-refresh"));
     connect(redownloadSelectedAction, SIGNAL(triggered()), SLOT(slotRedownloadSelected()));
 
-    QAction *startAllAction = actionCollection()->addAction("start_all_download");
+    KAction *startAllAction = actionCollection()->addAction("start_all_download");
     startAllAction->setText(i18n("Start / Resume All"));
     startAllAction->setIcon(KIcon("media-seek-forward"));
     startAllAction->setShortcuts(KShortcut("Ctrl+R"));
     connect(startAllAction, SIGNAL(triggered()), SLOT(slotStartAllDownload()));
 
-    QAction *startSelectedAction = actionCollection()->addAction("start_selected_download");
+    KAction *startSelectedAction = actionCollection()->addAction("start_selected_download");
     startSelectedAction->setText(i18n("Start / Resume Selected"));
     startSelectedAction->setIcon(KIcon("media-playback-start"));
     connect(startSelectedAction, SIGNAL(triggered()), SLOT(slotStartSelectedDownload()));
 
-    QAction *stopAllAction = actionCollection()->addAction("stop_all_download");
+    KAction *stopAllAction = actionCollection()->addAction("stop_all_download");
     stopAllAction->setText(i18n("Stop All"));
     stopAllAction->setIcon(KIcon("media-playback-pause"));
     stopAllAction->setShortcuts(KShortcut("Ctrl+P"));
     connect(stopAllAction, SIGNAL(triggered()), SLOT(slotStopAllDownload()));
 
-    QAction *stopSelectedAction = actionCollection()->addAction("stop_selected_download");
+    KAction *stopSelectedAction = actionCollection()->addAction("stop_selected_download");
     stopSelectedAction->setText(i18n("Stop Selected"));
     stopSelectedAction->setIcon(KIcon("media-playback-pause"));
     connect(stopSelectedAction, SIGNAL(triggered()), SLOT(slotStopSelectedDownload()));
@@ -233,22 +275,22 @@ void MainWindow::setupActions()
     stopActionMenu->addAction(stopSelectedAction);
     connect(stopActionMenu, SIGNAL(triggered()), SLOT(slotStopDownload()));
 
-    QAction *openDestAction = actionCollection()->addAction("transfer_open_dest");
+    KAction *openDestAction = actionCollection()->addAction("transfer_open_dest");
     openDestAction->setText(i18n("Open Destination"));
     openDestAction->setIcon(KIcon("document-open"));
     connect(openDestAction, SIGNAL(triggered()), SLOT(slotTransfersOpenDest()));
 
-    QAction *openFileAction = actionCollection()->addAction("transfer_open_file");
+    KAction *openFileAction = actionCollection()->addAction("transfer_open_file");
     openFileAction->setText(i18n("Open File"));
     openFileAction->setIcon(KIcon("document-open"));
     connect(openFileAction, SIGNAL(triggered()), SLOT(slotTransfersOpenFile()));
 
-    QAction *showDetailsAction = actionCollection()->addAction("transfer_show_details");
+    KAction *showDetailsAction = actionCollection()->addAction("transfer_show_details");
     showDetailsAction->setText(i18n("Show Details"));
     showDetailsAction->setIcon(KIcon("document-properties"));
     connect(showDetailsAction, SIGNAL(triggered()), SLOT(slotTransfersShowDetails()));
 
-    QAction *copyUrlAction = actionCollection()->addAction("transfer_copy_source_url");
+    KAction *copyUrlAction = actionCollection()->addAction("transfer_copy_source_url");
     copyUrlAction->setText(i18n("Copy URL to Clipboard"));
     copyUrlAction->setIcon(KIcon("edit-copy"));
     connect(copyUrlAction, SIGNAL(triggered()), SLOT(slotTransfersCopySourceUrl()));
@@ -259,26 +301,26 @@ void MainWindow::setupActions()
     showDropTargetAction->setChecked(Settings::showDropTarget());
     connect(showDropTargetAction, SIGNAL(triggered()), SLOT(slotToggleDropTarget()));
 
-    QAction *transferHistoryAction = actionCollection()->addAction("Transfer History");
-    transferHistoryAction->setText(i18n("&Transfer History"));
+    KAction *transferHistoryAction = actionCollection()->addAction("transfer_history");
+    transferHistoryAction->setText(i18n("&Transfer History..."));
     transferHistoryAction->setIcon(KIcon("view-history"));
     transferHistoryAction->setShortcuts(KShortcut("Ctrl+H"));
     connect(transferHistoryAction, SIGNAL(triggered()), SLOT(slotTransferHistory()));
 
-    QAction *transferGroupSettingsAction = actionCollection()->addAction("transfer_group_settings");
-    transferGroupSettingsAction->setText(i18n("&Group Settings"));
+    KAction *transferGroupSettingsAction = actionCollection()->addAction("transfer_group_settings");
+    transferGroupSettingsAction->setText(i18n("&Group Settings..."));
     transferGroupSettingsAction->setIcon(KIcon("preferences-system"));
     transferGroupSettingsAction->setShortcuts(KShortcut("Ctrl+G"));
     connect(transferGroupSettingsAction, SIGNAL(triggered()), SLOT(slotTransferGroupSettings()));
 
-    QAction *transferSettingsAction = actionCollection()->addAction("transfer_settings");
-    transferSettingsAction->setText(i18n("&Transfer Settings"));
+    KAction *transferSettingsAction = actionCollection()->addAction("transfer_settings");
+    transferSettingsAction->setText(i18n("&Transfer Settings..."));
     transferSettingsAction->setIcon(KIcon("preferences-system"));
     transferSettingsAction->setShortcuts(KShortcut("Ctrl+T"));
     connect(transferSettingsAction, SIGNAL(triggered()), SLOT(slotTransferSettings()));
 
-    QAction *listLinksAction = actionCollection()->addAction("import_links");
-    listLinksAction->setText(i18n("Import &Links"));
+    KAction *listLinksAction = actionCollection()->addAction("import_links");
+    listLinksAction->setText(i18n("Import &Links..."));
     listLinksAction->setIcon(KIcon("view-list-text"));
     listLinksAction->setShortcuts(KShortcut("Ctrl+L"));
     connect(listLinksAction, SIGNAL(triggered()), SLOT(slotShowListLinks()));
@@ -290,6 +332,7 @@ void MainWindow::slotDelayedInit()
     KGet::load( KStandardDirs::locateLocal("appdata", "transfers.kgt") );
 
     m_dock = new Tray(this);
+
     if(Settings::enableSystemTray()) {
         // DockWidget
         m_dock->show();
@@ -309,10 +352,6 @@ void MainWindow::slotDelayedInit()
     cfg.group(QString()).writeEntry("AutoResume", true);
     cfg.sync();
 
-    // immediately start downloading if configured this way
-    if ( Settings::downloadAtStartup() )
-        slotStartDownload();
-
     // DropTarget
     m_drop = new DropTarget(this);
 
@@ -369,7 +408,7 @@ void MainWindow::slotToggleDropTarget()
 
 void MainWindow::slotNewTransfer()
 {
-    NewTransferDialog::showNewTransferDialog();
+    NewTransferDialog::instance(this)->showDialog();
 }
 
 void MainWindow::slotImportTransfers()
@@ -388,6 +427,16 @@ void MainWindow::slotImportTransfers()
         KGet::addTransfer( KUrl( filename ) );
 }
 
+void MainWindow::slotUpdateTitlePercent()
+{
+    int percent = transfersPercent();
+    if (percent != -1) {
+        setPlainCaption(i18nc("window title including overall download progress in percent", "KGet - %1%", percent));
+    } else {
+        setPlainCaption(i18n("KGet"));
+    }
+}
+
 void MainWindow::slotQuit()
 {
     if (KGet::schedulerRunning()) {
@@ -415,7 +464,7 @@ void MainWindow::slotPreferences()
 
     // we didn't find an instance of this dialog, so lets create it
     PreferencesDialog * dialog = new PreferencesDialog( this, Settings::self() );
-    KGet::setPluginsSettingsWidget( dialog->pluginsWidget() );
+
     // keep us informed when the user changes settings
     connect( dialog, SIGNAL(settingsChanged(const QString&)),
              this, SLOT(slotNewConfig()) );
@@ -425,15 +474,12 @@ void MainWindow::slotPreferences()
 
 void MainWindow::slotExportTransfers()
 {
-    QString filename = KFileDialog::getSaveFileName
-        (KUrl(),
-         "*.kgt|" + i18n("KGet Transfer List") + " (*.kgt)",
-         this,
-         i18n("Export Transfers")
-        );
+    exportTransfers(false);
+}
 
-    if(!filename.isEmpty())
-        KGet::save(filename);
+void MainWindow::slotExportPlainTransfers()
+{
+    exportTransfers(true);
 }
 
 void MainWindow::slotDeleteGroup()
@@ -624,7 +670,9 @@ void MainWindow::slotNewConfig()
     m_viewsContainer->setExpandableDetails(Settings::showExpandableTransferDetails());
     m_drop->setDropTargetVisible(Settings::showDropTarget(), false);
     m_dock->setVisible(Settings::enableSystemTray());
-    if(!Settings::enableSystemTray()) setVisible(true);
+
+    if(!Settings::enableSystemTray())
+        setVisible(true);
 
     slotKonquerorIntegration(Settings::konquerorIntegration());
     m_konquerorIntegration->setChecked(Settings::konquerorIntegration());
@@ -692,12 +740,17 @@ void MainWindow::slotTrayKonquerorIntegration(bool enable)
     slotKonquerorIntegration(enable);
     if (!enable && Settings::konquerorIntegration() && !Settings::expertMode())
     {
-        KMessageBox::information(this,
+        KGet::showNotification(this, KNotification::Notification,
+                                     i18n("KGet has been temporarily disabled as download manager for Konqueror. "
+            "If you want to disable it forever, go to Settings->Advanced and disable \"Use "
+            "as download manager for Konqueror\"."),
+                                     "dialog-info");
+        /*KMessageBox::information(this,
             i18n("KGet has been temporarily disabled as download manager for Konqueror. "
             "If you want to disable it forever, go to Settings->Advanced and disable \"Use "
             "as download manager for Konqueror\"."),
             i18n("Konqueror Integration disabled"),
-            "KonquerorIntegrationDisabled");
+            "KonquerorIntegrationDisabled");*/
     }
 }
 
@@ -775,18 +828,31 @@ void MainWindow::slotImportUrl(const QString &url)
 }
 
 /** widget events */
-
 void MainWindow::closeEvent( QCloseEvent * e )
 {
-    e->ignore();
-    if(!Settings::enableSystemTray()) {
-        slotQuit();
-    }
-    else {
-        hide();
+    // if the event comes from out the application (close event) we decide between close or hide
+    // if the event comes from the application (system shutdown) we say goodbye
+    if(e->spontaneous()) {
+        e->ignore();
+        if(!Settings::enableSystemTray()) {
+            slotQuit();
+        }
+        else {
+            hide();
+        }
     }
 }
 
+void MainWindow::hideEvent(QHideEvent *)
+{
+    Settings::setShowMain(false);
+}
+
+void MainWindow::showEvent(QShowEvent *)
+{
+    Settings::setShowMain(true);
+}
+
 void MainWindow::dragEnterEvent(QDragEnterEvent * event)
 {
     event->setAccepted(KUrl::List::canDecode(event->mimeData())
@@ -807,7 +873,7 @@ void MainWindow::dropEvent(QDropEvent * event)
                                        KGuiItem(i18n("&Load transferlist"), KIcon("list-add")), KStandardGuiItem::cancel());
 
             if (msgBoxResult == 3) //Download
-                NewTransferDialog::showNewTransferDialog(list.first().url());
+                NewTransferDialog::instance(this)->showDialog(list.first().url());
             if (msgBoxResult == 4) //Load
                 KGet::load(list.first().url());
         }
@@ -816,25 +882,30 @@ void MainWindow::dropEvent(QDropEvent * event)
             if (list.count() == 1)
             {
                 str = event->mimeData()->text();
-                NewTransferDialog::showNewTransferDialog(str);
+                NewTransferDialog::instance(this)->showDialog(str);
             }
             else
-                NewTransferDialog::showNewTransferDialog(list);
+                NewTransferDialog::instance(this)->showDialog(list);
         }
     }
     else
     {
-        NewTransferDialog::showNewTransferDialog();
+        NewTransferDialog::instance(this)->showDialog();
     }
 }
 
 
 /** DBUS interface */
 
-void MainWindow::addTransfers(const QString& src, const QString& dest, bool start)
+void MainWindow::addTransfer(const QString& src, const QString& dest, bool start)
 {
     // split src for the case it is a QStringList (e.g. from konqueror plugin)
-    KGet::addTransfer(src.split(";"), dest, QString(), start);
+    KGet::addTransfer(src.split(';'), dest, QString(), start);
+}
+
+void MainWindow::showNewTransferDialog(const QStringList &urls)
+{
+    NewTransferDialog::instance(this)->showDialog(urls);
 }
 
 bool MainWindow::dropTargetVisible() const
@@ -868,4 +939,72 @@ int MainWindow::transfersSpeed() const
     return m_dbusModelObserver->transfersSpeed();
 }
 
+MainWindowModelObserver::MainWindowModelObserver(MainWindow *window) 
+    : QObject(window)
+{
+    m_window = window;
+    m_groupObserver = new MainWindowGroupObserver(window);
+}
+
+void MainWindowModelObserver::addedTransferGroupEvent(TransferGroupHandler *group)
+{
+    group->addObserver(m_groupObserver);
+}
+
+void MainWindowModelObserver::removedTransferGroupEvent(TransferGroupHandler *group)
+{
+    group->delObserver(m_groupObserver);
+}
+
+MainWindowGroupObserver::MainWindowGroupObserver(MainWindow *window) 
+    : QObject(window)
+{
+    m_window = window;
+    m_transferObserver = new MainWindowTransferObserver(window);
+}
+
+void MainWindowGroupObserver::groupChangedEvent(TransferGroupHandler * group)
+{
+    TransferGroupHandler::ChangesFlags transferFlags = group->changesFlags(this);
+    if (transferFlags & TransferGroup::Gc_Percent) {
+        m_window->slotUpdateTitlePercent();
+    }
+    group->resetChangesFlags(this);
+}
+
+void MainWindowGroupObserver::addedTransferEvent(TransferHandler * transfer, TransferHandler * after)
+{ 
+    Q_UNUSED(after);
+    transfer->addObserver(m_transferObserver);
+}
+
+void MainWindowGroupObserver::removedTransferEvent(TransferHandler * transfer)
+{
+    transfer->delObserver(m_transferObserver);
+
+    m_window->slotUpdateTitlePercent();
+}
+
+/**
+void MainWindowGroupObserver::movedTransferEvent(TransferHandler * transfer, TransferHandler * after)
+{
+    Q_UNUSED(transfer);
+    Q_UNUSED(after);
+}**/
+
+MainWindowTransferObserver::MainWindowTransferObserver(MainWindow *window)
+    : QObject(window)
+{
+    m_window = window;
+}
+
+void MainWindowTransferObserver::transferChangedEvent(TransferHandler *transfer)
+{
+    TransferHandler::ChangesFlags transferFlags = transfer->changesFlags(this);
+    if (transferFlags & Transfer::Tc_Percent || transferFlags & Transfer::Tc_Status) {
+        m_window->slotUpdateTitlePercent();
+    }
+    transfer->resetChangesFlags(this);
+}
+
 #include "mainwindow.moc"
