@@ -1,7 +1,7 @@
 /*
     chatview.h - Chat View
 
-    Copyright (c) 2002-2004 by Olivier Goffart       <ogoffart @ kde.org>
+    Copyright (c) 2002-2004 by Olivier Goffart       <ogoffart@kde.org>
 
     Kopete    (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
 
@@ -18,22 +18,25 @@
 #ifndef CHATVIEW_H
 #define CHATVIEW_H
 
+
 #include "kopeteview.h"
 #include "kopeteviewplugin.h"
-#include <kdockwidget.h>
+//#include <k3dockwidget.h>
 #include <ktextedit.h> // for covariant return type of editWidget
-#include <qptrdict.h>
+#include <QDragEnterEvent>
+#include <QDropEvent>
+#include <QMap>
+#include <kvbox.h>
+
+#include <kopete_export.h>
 
 class QTimer;
 
 class ChatTextEditPart;
-class ChatMembersListWidget;
 class ChatMessagePart;
 
 class KopeteChatWindow;
 
-class KTabWidget;
-
 class KopeteChatViewPrivate;
 class ChatWindowPlugin;
 
@@ -46,22 +49,25 @@ namespace Kopete
 {
 	class Contact;
 	class ChatSession;
+	class OnlineStatus;
+	class PropertyContainer;
 }
 
+typedef QMap<const Kopete::Contact*,QTimer*> TypingMap;
+
 /**
  * @author Olivier Goffart
  */
-class ChatView : public KDockMainWindow, public KopeteView
+class ChatView : public KVBox, public KopeteView
 {
 	Q_OBJECT
 public:
-	ChatView( Kopete::ChatSession *manager, ChatWindowPlugin *parent, const char *name = 0 );
+	ChatView( Kopete::ChatSession *manager, ChatWindowPlugin *parent );
 	~ChatView();
 
 	/** the state of our chat */
 	enum KopeteTabState { Normal, Highlighted, Changed, Typing, Message, Undefined };
 
-	ChatMembersListWidget *membersList() const { return m_membersList; }
 	ChatMessagePart *messagePart() const { return m_messagePart; }
 	ChatTextEditPart *editPart() const { return m_editPart; }
 
@@ -125,36 +131,12 @@ public:
 	 */
 	virtual void setCurrentMessage( const Kopete::Message &newMessage );
 
-	/**
-	 * Sets the placement of the chat members list.
-	 * DockLeft, DockRight, or DockNone.
-	 * @param dp The dock position of the list
-	 */
-	void placeMembersList( KDockWidget::DockPosition dp = KDockWidget::DockRight );
-
-	/**
-	 * Shows or hides the chat members list
-	 */
-	void toggleMembersVisibility();
-
 	/**
 	 * Returns the chat window this view is in
 	 * @return The chat window
 	 */
 	KopeteChatWindow *mainWindow() const { return m_mainWindow; }
 
-	/**
-	 * Returns the current position of the chat member slist
-	 * @return The position of the chat members list
-	 */
-	const KDockWidget::DockPosition membersListPosition()  { return membersDockPosition; }
-
-	/**
-	 * Returns whether or not the chat member list is visible
-	 * @return Is the chat member list visible?
-	 */
-	bool visibleMembersList();
-
 	const QString &statusText();
 
 	QString &caption() const;
@@ -176,7 +158,8 @@ public:
 	KTextEdit *editWidget();
 
 	bool canSend();
-
+	bool canSendFile();
+	
 	/** Reimplemented from KopeteView **/
 	virtual void registerContextMenuHandler( QObject *target, const char* slot );
 
@@ -226,6 +209,11 @@ public slots:
 	 */
 	QFont font();
 
+	/**
+	 * Reset font and color of the edit area and outgoing messages.
+	 */
+	void resetFontAndColor();
+
 	/**
 	 * Sets the background color of the entry area, and outgoing messages
 	 * @param newColor The new background color. If this is QColor(), then
@@ -244,6 +232,11 @@ public slots:
 	 */
 	virtual void appendMessage( Kopete::Message &message );
 
+	/**
+	 * Send file (opens file dialog)
+	 */
+	void sendFile();
+
 	/**
 	 * Called when a typing event is received from a contact
 	 * Updates the typing map and outputs the typing message into the status area
@@ -262,6 +255,9 @@ public slots:
 	virtual void messageSentSuccessfully();
 
 	virtual bool closeView( bool force = false );
+	
+	/** Retrieves the tab state. */
+	KopeteTabState tabState() const;
 
 signals:
 	/**
@@ -299,6 +295,8 @@ signals:
 	 */
 	void canSendChanged(bool);
 
+	void canAcceptFilesChanged();
+
 	/**
 	 * Emitted when we re-parent ourselves with a new window
 	 */
@@ -316,7 +314,7 @@ private slots:
 	/**
 	 * Show that a contact changed his nickname when a metacontact is not avaiable.
 	 */
-	void slotPropertyChanged( Kopete::Contact *contact, const QString &key, const QVariant &oldValue, const QVariant &newValue  );
+	void slotPropertyChanged( Kopete::PropertyContainer *contact, const QString &key, const QVariant &oldValue, const QVariant &newValue  );
 
 	/**
 	 * Called when a contact is added to the chat session.
@@ -334,7 +332,7 @@ private slots:
 	 * @param format The format of the reason message
 	 * @param suppressNotification mean that no notifications are showed
 	 */
-	void slotContactRemoved( const Kopete::Contact *c, const QString& reason, Kopete::Message::MessageFormat format, bool suppressNotification=false );
+	void slotContactRemoved( const Kopete::Contact *c, const QString& reason, Qt::TextFormat format, bool suppressNotification=false );
 
 	/**
 	 * Called when a contact changes status, updates the display name, status icon and tab bar state.
@@ -361,46 +359,38 @@ private slots:
 
 protected:
 	virtual void dragEnterEvent ( QDragEnterEvent * );
+	virtual void dragMoveEvent ( QDragMoveEvent * );
 	virtual void dropEvent ( QDropEvent * );
 
 private:
 	// widget stuff
 	KopeteChatWindow *m_mainWindow;
 
-	KDockWidget *viewDock;
+//	K3DockWidget *viewDock;
 	ChatMessagePart *m_messagePart;
 
-	KDockWidget *membersDock;
-	ChatMembersListWidget *m_membersList;
-
-	KDockWidget *editDock;
+//	K3DockWidget *editDock;
 	ChatTextEditPart *m_editPart;
 
 	KopeteTabState m_tabState;
 
-	// position and visibility of the chat member list
-	KDockWidget::DockPosition membersDockPosition;
-	enum MembersListPolicy { Smart = 0, Visible = 1, Hidden = 2 };
-	MembersListPolicy membersStatus;
-
 	// miscellany
-	QPtrDict<QTimer> m_remoteTypingMap;
+	TypingMap m_remoteTypingMap;
 	QString unreadMessageFrom;
 	QString m_status;
 
 	void updateChatState( KopeteTabState state = Undefined );
 
-	/**
-	 * Creates the members list widget
-	 */
-	void createMembersList();
-
 	/**
 	 * Read in saved options, such as splitter positions
 	 */
 	void readOptions();
 
-	void sendInternalMessage( const QString &msg, Kopete::Message::MessageFormat format = Kopete::Message::PlainText );
+	void sendInternalMessage( const QString &msg, Qt::TextFormat format = Qt::PlainText );
+	
+	KopeteTabState currentState() const;
+
+	bool isDragEventAccepted( QDragMoveEvent * ) const;
 
 	KopeteChatViewPrivate *d;
 };
@@ -411,7 +401,7 @@ private:
 class ChatWindowPlugin : public Kopete::ViewPlugin
 {
 	public:
-		ChatWindowPlugin(QObject *parent, const char *name, const QStringList &args);
+		ChatWindowPlugin(QObject *parent, const QVariantList &args);
 		KopeteView* createView( Kopete::ChatSession *manager );
 };
 
