@@ -20,21 +20,16 @@
     *************************************************************************
 */
 
-#include <QTimer>
-#include <QLayout>
-
-#include <QFileInfo>
-#include <QDockWidget>
-
-//Added by qt3to4:
-#include <QPixmap>
-#include <QTextStream>
-#include <QCloseEvent>
-#include <QFrame>
-#include <QLabel>
-#include <QVBoxLayout>
-#include <QMenu>
-#include <QDockWidget>
+#include <QtCore/QTextStream>
+#include <QtCore/QTimer>
+#include <QtGui/QDockWidget>
+#include <QtGui/QFrame>
+#include <QtGui/QLabel>
+#include <QtGui/QLayout>
+#include <QtGui/QMenu>
+#include <QtGui/QPixmap>
+#include <QtGui/QCloseEvent>
+#include <QtGui/QVBoxLayout>
 
 #ifdef CHRONO
 #include <QTime>
@@ -55,7 +50,6 @@
 #include <kstatusbar.h>
 #include <kpushbutton.h>
 #include <ktabwidget.h>
-#include <kstandarddirs.h>
 #include <kdialog.h>
 #include <kstringhandler.h>
 #include <ksqueezedtextlabel.h>
@@ -108,7 +102,7 @@ namespace
 KopeteChatWindow *KopeteChatWindow::window( Kopete::ChatSession *manager )
 {
 	bool windowCreated = false;
-	KopeteChatWindow *myWindow;
+	KopeteChatWindow *myWindow = 0;
 
 	//Take the first and the first? What else?
 	Kopete::Group *group = 0L;
@@ -320,6 +314,7 @@ KopeteChatWindow::~KopeteChatWindow()
 
 	delete backgroundFile;
 	delete anim;
+	delete animIcon;
 }
 
 void KopeteChatWindow::windowListChanged()
@@ -329,12 +324,6 @@ void KopeteChatWindow::windowListChanged()
 		(*it)->checkDetachEnable();
 }
 
-void KopeteChatWindow::slotNickComplete()
-{
-	if( m_activeView )
-		m_activeView->nickComplete();
-}
-
 void KopeteChatWindow::slotTabContextMenu( QWidget *tab, const QPoint &pos )
 {
 	m_popupView = static_cast<ChatView*>( tab );
@@ -365,51 +354,63 @@ void KopeteChatWindow::initActions(void)
 	createStandardStatusBarAction();
 
 	chatSend = new KAction( KIcon("mail-send"), i18n( "&Send Message" ), coll );
-        coll->addAction( "chat_send", chatSend );
+	coll->addAction( "chat_send", chatSend );
 	connect( chatSend, SIGNAL( triggered(bool) ), SLOT( slotSendMessage() ) );
 	//Default to 'Return' for sending messages
 	chatSend->setShortcut( QKeySequence(Qt::Key_Return) );
 	chatSend->setEnabled( false );
 
- 	KStandardAction::save ( this, SLOT(slotChatSave()), coll );
- 	KStandardAction::print ( this, SLOT(slotChatPrint()), coll );
+	chatSendFile = new KAction( KIcon("mail-attachment"), i18n( "Send File" ), coll );
+	coll->addAction( "chat_send_file", chatSendFile );
+	connect( chatSendFile, SIGNAL( triggered(bool) ), SLOT( slotSendFile() ) );
+	chatSendFile->setEnabled( false );
+
+	KStandardAction::save ( this, SLOT(slotChatSave()), coll );
+	KStandardAction::print ( this, SLOT(slotChatPrint()), coll );
 	KAction* quitAction = KStandardAction::quit ( this, SLOT(close()), coll );
 	quitAction->setText( i18n("Close All Chats") );
 
 	tabClose = KStandardAction::close ( this, SLOT(slotChatClosed()), coll );
-        coll->addAction( "tabs_close", tabClose );
+	coll->addAction( "tabs_close", tabClose );
+
+	tabActive=new KAction( i18n( "&Activate Next Active Tab" ), coll );
+	coll->addAction( "tabs_active", tabActive );
+// 	tabActive->setShortcut( KStandardShortcut::tabNext() );
+	tabActive->setEnabled( false );
+	connect( tabActive, SIGNAL(triggered(bool)), this, SLOT(slotNextActiveTab()) );
 
 	tabRight=new KAction( i18n( "&Activate Next Tab" ), coll );
-        coll->addAction( "tabs_right", tabRight );
+	coll->addAction( "tabs_right", tabRight );
 	tabRight->setShortcut( KStandardShortcut::tabNext() );
 	tabRight->setEnabled( false );
 	connect( tabRight, SIGNAL(triggered(bool)), this, SLOT(slotNextTab()) );
 
 	tabLeft=new KAction( i18n( "&Activate Previous Tab" ), coll );
-        coll->addAction( "tabs_left", tabLeft );
+	coll->addAction( "tabs_left", tabLeft );
 	tabLeft->setShortcut( KStandardShortcut::tabPrev() );
 	tabLeft->setEnabled( false );
 	connect( tabLeft, SIGNAL(triggered(bool)), this, SLOT(slotPreviousTab()) );
 
+	// This action exists mostly so that the shortcut is configurable.
+	// The actual "slot" is the eventFilter.
 	nickComplete = new KAction( i18n( "Nic&k Completion" ), coll );
-        coll->addAction( "nick_complete", nickComplete );
-	connect( nickComplete, SIGNAL(triggered(bool)), this, SLOT(slotNickComplete()));
+	coll->addAction( "nick_complete", nickComplete );
 	nickComplete->setShortcut( QKeySequence( Qt::Key_Tab ) );
 
 	tabDetach = new KAction( KIcon("tab-detach"), i18n( "&Detach Chat" ), coll );
-        coll->addAction( "tabs_detach", tabDetach );
+	coll->addAction( "tabs_detach", tabDetach );
 	tabDetach->setEnabled( false );
 	connect( tabDetach, SIGNAL(triggered(bool)), this, SLOT( slotDetachChat() ));
 
 	actionDetachMenu = new KActionMenu( KIcon("tab-detach"), i18n( "&Move Tab to Window" ), coll );
-        coll->addAction( "tabs_detachmove", actionDetachMenu );
+	coll->addAction( "tabs_detachmove", actionDetachMenu );
 	actionDetachMenu->setDelayed( false );
 
 	connect ( actionDetachMenu->menu(), SIGNAL(aboutToShow()), this, SLOT(slotPrepareDetachMenu()) );
 	connect ( actionDetachMenu->menu(), SIGNAL(triggered(QAction*)), this, SLOT(slotDetachChat(QAction*)) );
 
 	actionTabPlacementMenu = new KActionMenu( i18n( "&Tab Placement" ), coll );
-        coll->addAction( "tabs_placement", actionTabPlacementMenu );
+	coll->addAction( "tabs_placement", actionTabPlacementMenu );
 	connect ( actionTabPlacementMenu->menu(), SIGNAL(aboutToShow()), this, SLOT(slotPreparePlacementMenu()) );
 	connect ( actionTabPlacementMenu->menu(), SIGNAL(triggered(QAction*)), this, SLOT(slotPlaceTabs(QAction*)) );
 
@@ -420,37 +421,45 @@ void KopeteChatWindow::initActions(void)
 	KStandardAction::paste( this, SLOT(slotPaste()), coll);
 
 	KAction* action;
-	action = new KAction( KIcon("preferences-desktop-font"), i18n( "Set Default &Font..." ), coll );
-        coll->addAction( "format_font", action );
+	action = new KAction( KIcon("preferences-desktop-font"), i18n( "Set &Font..." ), coll );
+	coll->addAction( "format_font", action );
 	connect( action, SIGNAL(triggered(bool)), this, SLOT(slotSetFont()) );
 
-	action = new KAction( KIcon("format-stroke-color"), i18n( "Set Default Text &Color..." ), coll );
-        coll->addAction( "format_fgcolor", action );
+	action = new KAction( KIcon("format-stroke-color"), i18n( "Reset Font And Color" ), coll );
+	coll->addAction( "format_font_and_color_reset", action );
+	connect( action, SIGNAL(triggered(bool)), this, SLOT(slotResetFontAndColor()) );
+
+	action = new KAction( KIcon("format-text-color"), i18n( "Set Text &Color..." ), coll );
+	coll->addAction( "format_fgcolor", action );
 	connect( action, SIGNAL(triggered(bool)), this, SLOT(slotSetFgColor()) );
 
 	action = new KAction( KIcon("format-fill-color"), i18n( "Set &Background Color..." ), coll );
-        coll->addAction( "format_bgcolor", action );
+	coll->addAction( "format_bgcolor", action );
 	connect( action, SIGNAL(triggered()), this, SLOT(slotSetBgColor()) );
 
+	toggleRichText = new KToggleAction( KIcon("draw-freehand"), i18n("Enable &Rich Text"), this );
+	coll->addAction( "enable_richtext", toggleRichText );
+	connect( toggleRichText, SIGNAL(toggled(bool)), this, SLOT(toggleRichTextAction(bool)) );
+
 	historyUp = new KAction( i18n( "Previous History" ), coll );
-        coll->addAction( "history_up", historyUp );
+	coll->addAction( "history_up", historyUp );
 	historyUp->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_Up) );
 	connect( historyUp, SIGNAL(triggered(bool)), this, SLOT(slotHistoryUp()) );
 
 	historyDown = new KAction( i18n( "Next History" ), coll );
-        coll->addAction( "history_down", historyDown );
+	coll->addAction( "history_down", historyDown );
 	historyDown->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_Down) );
 	connect( historyDown, SIGNAL(triggered(bool)), this, SLOT(slotHistoryDown()) );
 
 	action = KStandardAction::prior( this, SLOT( slotPageUp() ), coll );
-        coll->addAction( "scroll_up", action );
+	coll->addAction( "scroll_up", action );
 	action = KStandardAction::next( this, SLOT( slotPageDown() ), coll );
-        coll->addAction( "scroll_down", action );
+	coll->addAction( "scroll_down", action );
 
 	KStandardAction::showMenubar( menuBar(), SLOT(setVisible(bool)), coll );
 
 	toggleAutoSpellCheck = new KToggleAction( i18n( "Automatic Spell Checking" ), coll );
-        coll->addAction( "enable_auto_spell_check", toggleAutoSpellCheck );
+	coll->addAction( "enable_auto_spell_check", toggleAutoSpellCheck );
 	toggleAutoSpellCheck->setChecked( true );
 	connect( toggleAutoSpellCheck, SIGNAL(triggered(bool)), this, SLOT(toggleAutoSpellChecking()) );
 
@@ -461,12 +470,12 @@ void KopeteChatWindow::initActions(void)
 	coll->addAction ( "show_participants_widget", toggleParticipantsAction );
 
 	actionSmileyMenu = new KopeteEmoticonAction( coll );
-        coll->addAction( "format_smiley", actionSmileyMenu );
+	coll->addAction( "format_smiley", actionSmileyMenu );
 	actionSmileyMenu->setDelayed( false );
 	connect(actionSmileyMenu, SIGNAL(activated(const QString &)), this, SLOT(slotSmileyActivated(const QString &)));
 
 	actionContactMenu = new KActionMenu(i18n("Co&ntacts"), coll );
-        coll->addAction( "contacts_menu", actionContactMenu );
+	coll->addAction( "contacts_menu", actionContactMenu );
 	actionContactMenu->setDelayed( false );
 	connect ( actionContactMenu->menu(), SIGNAL(aboutToShow()), this, SLOT(slotPrepareContactMenu()) );
 
@@ -477,21 +486,17 @@ void KopeteChatWindow::initActions(void)
 
 	//The Sending movie
 	normalIcon = QPixmap( BarIcon( QLatin1String( "kopete" ) ) );
-#if 0
-	animIcon = KGlobal::iconLoader()->loadMovie( QLatin1String( "newmessage" ), KIconLoader::Toolbar);
 
-	// Pause the animation because otherwise it's running even when we're not
-	// showing it. This eats resources, and also triggers a pixmap leak in
-	// QMovie in at least Qt 3.1, Qt 3.2 and the current Qt 3.3 beta
-	if( !animIcon.isNull() )  //and another QT bug:  it crash if we pause a null movie
-		animIcon.pause();
-#endif
 	// we can't set the tool bar as parent, if we do, it will be deleted when we configure toolbars
 	anim = new QLabel( QString::null, 0L );	//krazy:exclude=nullstrassign for old broken gcc
 	anim->setObjectName( QLatin1String("kde toolbar widget") );
 	anim->setMargin(5);
 	anim->setPixmap( normalIcon );
 
+	animIcon = KIconLoader::global()->loadMovie( QLatin1String( "newmessage" ), KIconLoader::Toolbar);
+	if ( animIcon )
+		animIcon->setPaused(true);
+
 	KAction *animAction = new KAction( i18n("Toolbar Animation"), coll );
         coll->addAction( "toolbar_animation", animAction );
 	animAction->setDefaultWidget( anim );
@@ -520,8 +525,8 @@ void KopeteChatWindow::slotStopAnimation( ChatView* view )
 	if( view == m_activeView )
 	{
 		anim->setPixmap( normalIcon );
-		if( animIcon.state() == QMovie::Running )
-			animIcon.setPaused( true );
+		if( animIcon && animIcon->state() == QMovie::Running )
+			animIcon->setPaused( true );
 	}
 }
 
@@ -535,6 +540,14 @@ void KopeteChatWindow::slotUpdateSendEnabled()
 		m_button_send->setEnabled( enabled );
 }
 
+void KopeteChatWindow::updateChatSendFileAction()
+{
+	if ( !m_activeView )
+		return;
+	
+	chatSendFile->setEnabled( m_activeView->canSendFile() );
+}
+
 void KopeteChatWindow::toggleAutoSpellChecking()
 {
 	if ( !m_activeView )
@@ -559,6 +572,27 @@ void KopeteChatWindow::enableSpellCheckAction(bool enable)
 	toggleAutoSpellCheck->setChecked( enable );
 }
 
+void KopeteChatWindow::updateRichTextAction()
+{
+	if ( !m_activeView )
+		return;
+
+	toggleRichText->setEnabled( m_activeView->editPart()->isRichTextAvailable() );
+	toggleRichText->setChecked( m_activeView->editPart()->isRichTextEnabled() );
+}
+
+void KopeteChatWindow::toggleRichTextAction( bool enable )
+{
+	m_activeView->editPart()->setRichTextEnabled( enable );
+}
+
+void KopeteChatWindow::updateActions()
+{
+	updateSpellCheckAction();
+	updateRichTextAction();
+	updateChatSendFileAction();
+}
+
 void KopeteChatWindow::slotHistoryUp()
 {
 	if( m_activeView )
@@ -604,6 +638,11 @@ void KopeteChatWindow::slotSetFont()
 	m_activeView->setFont();
 }
 
+void KopeteChatWindow::slotResetFontAndColor()
+{
+	m_activeView->resetFontAndColor();
+}
+
 void KopeteChatWindow::slotSetFgColor()
 {
 	m_activeView->setFgColor();
@@ -745,9 +784,8 @@ void KopeteChatWindow::attachChatView( ChatView* newView )
 	connect( newView, SIGNAL(updateStatusIcon( ChatView* ) ), this, SLOT(slotUpdateCaptionIcons( ChatView* ) ) );
 	connect( newView, SIGNAL(updateChatState( ChatView*, int ) ), this, SLOT( updateChatState( ChatView*, int ) ) );
 
-	updateSpellCheckAction();
+	updateActions();
 	checkDetachEnable();
-	newView->loadChatSettings();
 	connect( newView, SIGNAL(autoSpellCheckEnabled( ChatView*, bool ) ),
 	         this, SLOT( slotAutoSpellCheckEnabled( ChatView*, bool ) ) );
 }
@@ -758,6 +796,7 @@ void KopeteChatWindow::checkDetachEnable()
 	tabDetach->setEnabled( haveTabs );
 	tabLeft->setEnabled( haveTabs );
 	tabRight->setEnabled( haveTabs );
+	tabActive->setEnabled( haveTabs );
 	actionTabPlacementMenu->setEnabled( m_tabBar != 0 );
 
 	bool otherWindows = (windows.count() > 1);
@@ -854,6 +893,20 @@ void KopeteChatWindow::slotNextTab()
 		m_tabBar->setCurrentIndex( curPage + 1 );
 }
 
+void KopeteChatWindow::slotNextActiveTab()
+{
+	int curPage = m_tabBar->currentIndex();
+	for(int i=(curPage+1) % m_tabBar->count(); i!=curPage; i = (i+1) % m_tabBar->count())
+	{
+		ChatView *v = static_cast<ChatView*>(m_tabBar->widget(i)); //We assume we only have ChatView's
+		if(v->tabState()==ChatView::Highlighted || v->tabState()==ChatView::Message)
+		{
+			m_tabBar->setCurrentIndex( i );
+			break;
+		}
+	}
+}
+
 void KopeteChatWindow::slotSetCaption( bool active )
 {
 	if( active && m_activeView )
@@ -889,8 +942,10 @@ void KopeteChatWindow::setActiveView( QWidget *widget )
 
 	if(m_activeView)
 	{
-		disconnect( m_activeView->editWidget(), SIGNAL( checkSpellingChanged(bool) ), this, SLOT( enableSpellCheckAction(bool) ) );
-		disconnect( m_activeView, SIGNAL( canSendChanged(bool) ), this, SLOT( slotUpdateSendEnabled() ) );
+		disconnect( m_activeView->editWidget(), SIGNAL(checkSpellingChanged(bool)), this, SLOT(enableSpellCheckAction(bool)) );
+		disconnect( m_activeView->editPart(), SIGNAL(richTextChanged()), this, SLOT(updateRichTextAction()) );
+		disconnect( m_activeView, SIGNAL(canSendChanged(bool)), this, SLOT(slotUpdateSendEnabled()) );
+		disconnect( m_activeView, SIGNAL(canAcceptFilesChanged()), this, SLOT(updateChatSendFileAction()) );
 		guiFactory()->removeClient(m_activeView->msgManager());
 		m_activeView->saveChatSettings();
 	}
@@ -910,8 +965,10 @@ void KopeteChatWindow::setActiveView( QWidget *widget )
 	if( chatViewList.indexOf( view ) == -1)
 		attachChatView( view );
 
-	connect( m_activeView->editWidget(), SIGNAL( checkSpellingChanged(bool) ), this, SLOT( enableSpellCheckAction(bool) ) );
-	connect( m_activeView, SIGNAL( canSendChanged(bool) ), this, SLOT( slotUpdateSendEnabled() ) );
+	connect( m_activeView->editWidget(), SIGNAL(checkSpellingChanged(bool)), this, SLOT(enableSpellCheckAction(bool)) );
+	connect( m_activeView->editPart(), SIGNAL(richTextChanged()), this, SLOT(updateRichTextAction()) );
+	connect( m_activeView, SIGNAL(canSendChanged(bool)), this, SLOT(slotUpdateSendEnabled()) );
+	connect( m_activeView, SIGNAL(canAcceptFilesChanged()), this, SLOT(updateChatSendFileAction()) );
 
 	//Tell it it is active
 	m_activeView->setActive( true );
@@ -919,19 +976,18 @@ void KopeteChatWindow::setActiveView( QWidget *widget )
 	//Update icons to match
 	slotUpdateCaptionIcons( m_activeView );
 
-#if 0
-	if ( m_activeView->sendInProgress() && !animIcon.isNull() )
+	if ( m_activeView->sendInProgress() && animIcon )
 	{
-		anim->setMovie( &animIcon );
-		animIcon.unpause();
+		anim->setMovie( animIcon );
+		animIcon->setPaused(false);
 	}
 	else
 	{
 		anim->setPixmap( normalIcon );
-		if( !animIcon.isNull() )
-			animIcon.pause();
+		if( animIcon )
+			animIcon->setPaused(true);
 	}
-#endif
+
 	if ( m_alwaysShowTabs || chatViewList.count() > 1 )
 	{
 		if( !m_tabBar )
@@ -943,9 +999,8 @@ void KopeteChatWindow::setActiveView( QWidget *widget )
 	setCaption( m_activeView->caption() );
 	setStatus( m_activeView->statusText() );
 	m_activeView->setFocus();
-	updateSpellCheckAction();
+	updateActions();
 	slotUpdateSendEnabled();
-	m_activeView->editPart()->reloadConfig();
 	m_activeView->loadChatSettings();
 
 	emit chatSessionChanged(m_activeView->msgManager());
@@ -1004,23 +1059,26 @@ void KopeteChatWindow::slotSendMessage()
 {
 	if ( m_activeView && m_activeView->canSend() )
 	{
-#if 0
-		if( !animIcon.isNull() )
+		if( animIcon )
 		{
-			anim->setMovie( &animIcon );
-			animIcon.unpause();
+			anim->setMovie( animIcon );
+			animIcon->setPaused(false);
 		}
-#endif
 		m_activeView->sendMessage();
 	}
 }
 
+void KopeteChatWindow::slotSendFile()
+{
+	if ( m_activeView )
+		m_activeView->sendFile();
+}
+
 void KopeteChatWindow::slotPrepareContactMenu(void)
 {
 	KMenu *contactsMenu = actionContactMenu->menu();
 	contactsMenu->clear();
 
-	Kopete::Contact *contact;
 	Kopete::ContactPtrList m_them;
 
 	if( m_popupView )
@@ -1033,7 +1091,7 @@ void KopeteChatWindow::slotPrepareContactMenu(void)
 	// 'Contacts' action, or something cleverer.
 	uint contactCount = 0;
 
-	foreach(contact, m_them)
+	foreach(Kopete::Contact *contact, m_them)
 	{
 		KMenu *p = contact->popupMenu();
 		connect ( actionContactMenu->menu(), SIGNAL(aboutToHide()),
@@ -1276,8 +1334,18 @@ void KopeteChatWindow::resizeEvent( QResizeEvent *e )
 		m_activeView->messagePart()->keepScrolledDown();
 }
 
+bool KopeteChatWindow::eventFilter( QObject *obj, QEvent *event )
+{
+	if ( m_activeView && obj == m_activeView->editWidget() && event->type() == QEvent::KeyPress ) {
+		 QKeyEvent *keyEvent = static_cast<QKeyEvent*>(event);
+		 if (nickComplete->shortcut().primary() == QKeySequence(keyEvent->key())) {
+			 m_activeView->nickComplete();
+			 return true;
+		 }
+	}
+	return KXmlGuiWindow::eventFilter(obj, event);
+}
 
 #include "kopetechatwindow.moc"
 
 // vim: set noet ts=4 sts=4 sw=4:
-
