@@ -77,6 +77,7 @@
 #include "kopeteapplication.h"
 #include "kopeteaccount.h"
 #include "kopeteaccountmanager.h"
+#include "kopeteaccountstatusbaricon.h"
 #include "kopeteidentitystatusbaricon.h"
 #include "kopetebehaviorsettings.h"
 #include "kopetecontact.h"
@@ -159,6 +160,7 @@ class KopeteWindow::Private
 				actionShowOfflineUsers ( 0 ), actionShowEmptyGroups ( 0 ), docked ( 0 ), deskRight ( 0 ),
 				statusBarWidget ( 0 ), tray ( 0 ), hidden ( false ), autoHide ( false ),
 				autoHideTimeout ( 0 ), autoHideTimer ( 0 ), addContactMapper ( 0 ),
+				showIdentityIcons( Kopete::AppearanceSettings::self()->showIdentityIcons() ),
 				globalStatusMessage ( 0 )
 		{}
 
@@ -205,7 +207,9 @@ class KopeteWindow::Private
 		QTimer *autoResizeTimer;
 		QSignalMapper *addContactMapper;
 
+		bool showIdentityIcons;
 		QHash<const Kopete::Identity*, KopeteIdentityStatusBarIcon*> identityStatusBarIcons;
+		QHash<const Kopete::Account*, KopeteAccountStatusBarIcon*> accountStatusBarIcons;
 		KSqueezedTextLabel *globalStatusMessage;
 };
 
@@ -519,11 +523,13 @@ void KopeteWindow::slotToggleAway()
 
 void KopeteWindow::initSystray()
 {
-	d->tray = KopeteSystemTray::systemTray ( this );
+	if ( Kopete::BehaviorSettings::self()->showSystemTray() ) {
+		d->tray = KopeteSystemTray::systemTray ( this );
 
-	QObject::connect ( d->tray, SIGNAL ( aboutToShowMenu ( KMenu * ) ),
-	                   this, SLOT ( slotTrayAboutToShowMenu ( KMenu * ) ) );
-	QObject::connect ( d->tray, SIGNAL ( quitSelected() ), this, SLOT ( slotQuit() ) );
+		QObject::connect ( d->tray, SIGNAL ( aboutToShowMenu ( KMenu * ) ),
+						   this, SLOT ( slotTrayAboutToShowMenu ( KMenu * ) ) );
+		QObject::connect ( d->tray, SIGNAL ( quitSelected() ), this, SLOT ( slotQuit() ) );
+	}
 }
 
 KopeteWindow::~KopeteWindow()
@@ -559,8 +565,9 @@ void KopeteWindow::loadOptions()
 
 	applyMainWindowSettings ( config->group ( "General Options" ) );
 	KConfigGroup cg ( config, "General Options" );
-	QPoint pos = cg.readEntry ( "Position", QPoint() );
-	move ( pos );
+	QPoint pos = cg.readEntry ( "Position", QPoint(-1, -1) );
+	if ( pos.x() != -1 || pos.y() != -1 )
+		move ( pos );
 
 	QSize size = cg.readEntry ( "Geometry", QSize() );
 	if ( size.isEmpty() ) // Default size
@@ -652,6 +659,53 @@ void KopeteWindow::slotConfigChanged()
 	d->actionShowAllOfflineEmpty->setChecked ( Kopete::AppearanceSettings::self()->showOfflineUsers() && Kopete::AppearanceSettings::self()->showEmptyGroups() );
 	d->actionShowOfflineUsers->setChecked ( Kopete::AppearanceSettings::self()->showOfflineUsers() );
 	d->actionShowEmptyGroups->setChecked ( Kopete::AppearanceSettings::self()->showEmptyGroups() );
+
+	if ( d->showIdentityIcons != Kopete::AppearanceSettings::self()->showIdentityIcons() )
+	{
+		// Delete status bar icons
+		if ( d->showIdentityIcons )
+		{
+			if ( d->identitywidget->isVisible() )
+			{
+				d->identitywidget->setIdentity( 0 );
+				d->identitywidget->setVisible( false );
+			}
+
+			qDeleteAll( d->identityStatusBarIcons );
+			d->identityStatusBarIcons.clear();
+		}
+		else
+		{
+			qDeleteAll( d->accountStatusBarIcons );
+			d->accountStatusBarIcons.clear();
+		}
+
+		// Add new status bar icons
+		d->showIdentityIcons = Kopete::AppearanceSettings::self()->showIdentityIcons();
+		if ( d->showIdentityIcons )
+		{
+			Kopete::Identity::List identityList = Kopete::IdentityManager::self()->identities();
+			foreach ( Kopete::Identity *identity, identityList )
+			{
+				KopeteIdentityStatusBarIcon *sbIcon = new KopeteIdentityStatusBarIcon ( identity, d->statusBarWidget );
+				connect ( sbIcon, SIGNAL(leftClicked(Kopete::Identity*, const QPoint&)), this,
+				          SLOT(slotIdentityStatusIconLeftClicked(Kopete::Identity*, const QPoint&)) );
+
+				d->identityStatusBarIcons.insert ( identity, sbIcon );
+				slotIdentityStatusIconChanged ( identity );
+				slotIdentityToolTipChanged ( identity );
+			}
+		}
+		else
+		{
+			QList<Kopete::Account *> accountList = Kopete::AccountManager::self()->accounts();
+			foreach ( Kopete::Account *account, accountList )
+			{
+				KopeteAccountStatusBarIcon *sbIcon = new KopeteAccountStatusBarIcon ( account, d->statusBarWidget );
+				d->accountStatusBarIcons.insert ( account, sbIcon );
+			}
+		}
+	}
 }
 
 void KopeteWindow::slotContactListAppearanceChanged()
@@ -800,12 +854,16 @@ void KopeteWindow::slotAllPluginsLoaded()
 	d->actionDisconnect->setEnabled ( true );
 
 	KConfigGroup cg( KGlobal::config(), "General Options" );
-	QString identityId = cg.readEntry( "ShownIdentityId", Kopete::IdentityManager::self()->defaultIdentity()->id() );
-	if ( !identityId.isEmpty() )
+
+	if ( d->showIdentityIcons )
 	{
-		Kopete::Identity* identity = Kopete::IdentityManager::self()->findIdentity( identityId );
-		if ( identity )
-			slotIdentityStatusIconLeftClicked( identity, QPoint() );
+		QString identityId = cg.readEntry( "ShownIdentityId", Kopete::IdentityManager::self()->defaultIdentity()->id() );
+		if ( !identityId.isEmpty() )
+		{
+			Kopete::Identity* identity = Kopete::IdentityManager::self()->findIdentity( identityId );
+			if ( identity )
+				slotIdentityStatusIconLeftClicked( identity, QPoint() );
+		}
 	}
 }
 
@@ -821,11 +879,15 @@ void KopeteWindow::slotIdentityRegistered ( Kopete::Identity *identity )
 	connect ( identity, SIGNAL(toolTipChanged(Kopete::Identity*)),
 	          this, SLOT(slotIdentityToolTipChanged(Kopete::Identity*)) );
 
-	KopeteIdentityStatusBarIcon *sbIcon = new KopeteIdentityStatusBarIcon ( identity, d->statusBarWidget );
-	connect ( sbIcon, SIGNAL ( leftClicked ( Kopete::Identity *, const QPoint & ) ),
-	          SLOT ( slotIdentityStatusIconLeftClicked ( Kopete::Identity *, const QPoint & ) ) );
+	if ( d->showIdentityIcons )
+	{
+		KopeteIdentityStatusBarIcon *sbIcon = new KopeteIdentityStatusBarIcon ( identity, d->statusBarWidget );
+		connect ( sbIcon, SIGNAL ( leftClicked ( Kopete::Identity *, const QPoint & ) ),
+		          SLOT ( slotIdentityStatusIconLeftClicked ( Kopete::Identity *, const QPoint & ) ) );
+
+		d->identityStatusBarIcons.insert ( identity, sbIcon );
+	}
 
-	d->identityStatusBarIcons.insert ( identity, sbIcon );
 	slotIdentityStatusIconChanged ( identity );
 	slotIdentityToolTipChanged( identity );
 }
@@ -834,13 +896,15 @@ void KopeteWindow::slotIdentityUnregistered ( const Kopete::Identity *identity )
 {
 	kDebug ( 14000 ) ;
 
-	KopeteIdentityStatusBarIcon *sbIcon = d->identityStatusBarIcons[identity];
-
-	if ( !sbIcon )
-		return;
-
-	d->identityStatusBarIcons.remove ( identity );
-	delete sbIcon;
+	if ( d->showIdentityIcons )
+	{
+		KopeteIdentityStatusBarIcon *sbIcon = d->identityStatusBarIcons.value ( identity, 0 );
+		if ( sbIcon )
+		{
+			d->identityStatusBarIcons.remove ( identity );
+			delete sbIcon;
+		}
+	}
 
 	makeTrayToolTip();
 
@@ -850,7 +914,7 @@ void KopeteWindow::slotIdentityToolTipChanged ( Kopete::Identity *identity )
 {
 	// Adds tooltip for each status icon, useful in case you have many accounts
 	// over one protocol
-	KopeteIdentityStatusBarIcon *i = d->identityStatusBarIcons[ identity ];
+	KopeteIdentityStatusBarIcon *i = d->identityStatusBarIcons.value ( identity, 0 );
 	if ( i )
 		i->setToolTip ( identity->toolTip() );
 
@@ -877,7 +941,7 @@ void KopeteWindow::slotIdentityStatusIconChanged ( Kopete::Identity *identity )
 		//Kopete::StatusManager::self()->setGlobalStatusMessage( identity->property( Kopete::Global::Properties::self()->statusMessage() ).value().toString() );
 	}
 
-	KopeteIdentityStatusBarIcon *i = d->identityStatusBarIcons[ identity ];
+	KopeteIdentityStatusBarIcon *i = d->identityStatusBarIcons.value ( identity, 0 );
 	if ( !i )
 		return;
 
@@ -998,6 +1062,11 @@ void KopeteWindow::slotAccountRegistered ( Kopete::Account *account )
 	d->addContactMapper->setMapping ( action, account->protocol()->pluginId() + QChar ( 0xE000 ) + account->accountId() );
 	d->actionAddContact->addAction ( action );
 
+	if ( !d->showIdentityIcons )
+	{
+		KopeteAccountStatusBarIcon *sbIcon = new KopeteAccountStatusBarIcon ( account, d->statusBarWidget );
+		d->accountStatusBarIcons.insert ( account, sbIcon );
+	}
 }
 
 void KopeteWindow::slotAccountUnregistered ( const Kopete::Account *account )
@@ -1018,6 +1087,16 @@ void KopeteWindow::slotAccountUnregistered ( const Kopete::Account *account )
 		d->addContactMapper->removeMappings ( action );
 		d->actionAddContact->removeAction ( action );
 	}
+
+	if ( !d->showIdentityIcons )
+	{
+		KopeteAccountStatusBarIcon *sbIcon = d->accountStatusBarIcons.value ( account, 0 );
+		if ( sbIcon )
+		{
+			d->accountStatusBarIcons.remove ( account );
+			delete sbIcon;
+		}
+	}
 }
 
 void KopeteWindow::slotTrayAboutToShowMenu ( KMenu * popup )
@@ -1108,7 +1187,7 @@ void KopeteWindow::setStatusMessage ( const Kopete::StatusMessage& statusMessage
 	{
 		Kopete::Contact *self = account->myself();
 		bool isInvisible = self && self->onlineStatus().status() == Kopete::OnlineStatus::Invisible;
-		if ( account->isConnected() && !isInvisible )
+		if ( self && account->isConnected() && !isInvisible )
 		{
 			changed = true;
 			account->setOnlineStatus ( self->onlineStatus(), statusMessage );
