@@ -216,7 +216,7 @@ private:
 
 private:
 	class Private;
-	Private *d;
+	Private * const d;
 };
 
 
