@@ -18,7 +18,8 @@
 #ifndef KOPETEMIMETYPEHANDLER_H
 #define KOPETEMIMETYPEHANDLER_H
 
-class KURL;
+#include <kurl.h>
+
 class QString;
 class QStringList;
 
@@ -46,7 +47,7 @@ public:
 	 *
 	 * @return true if a handler was registered for the mime type, false otherwise
 	 */
-	static bool dispatchURL( const KURL &url );
+	static bool dispatchURL( const KUrl &url );
 
 	/**
 	 * Returns a list of mime types this object is registered to handle
@@ -70,7 +71,7 @@ public:
 	 *
 	 * @param url The url to handle
 	 */
-	virtual void handleURL( const KURL &url ) const;
+	virtual void handleURL( const KUrl &url ) const;
 
 	/**
 	 * Handles the URL @p url, which has the mime type @p mimeType
@@ -78,7 +79,7 @@ public:
 	 * @param mimeType The mime type of the URL
 	 * @param url The url to handle
 	 */
-	virtual void handleURL( const QString &mimeType, const KURL &url ) const;
+	virtual void handleURL( const QString &mimeType, const KUrl &url ) const;
 
 protected:
 	/**
@@ -108,10 +109,10 @@ private:
 	 *
 	 * @return true if a handler was able to process the URL, false otherwise
 	 */
-	static bool dispatchToHandler( const KURL &url, const QString &mimeType, MimeTypeHandler *handler );
+	static bool dispatchToHandler( const KUrl &url, const QString &mimeType, MimeTypeHandler *handler );
 
 	class Private;
-	Private *d;
+	Private * const d;
 };
 
 /**
@@ -124,7 +125,7 @@ public:
 
 	const QStringList mimeTypes() const;
 
-	void handleURL( const QString &mimeType, const KURL &url ) const;
+	void handleURL( const QString &mimeType, const KUrl &url ) const;
 };
 
 } // Kopete
