@@ -29,6 +29,7 @@
 #include <qmap.h>
 
 #include <kaction.h>
+#include <KActionCollection>
 #include <kdebug.h>
 #include <kicon.h>
 #include <klocale.h>
@@ -66,11 +67,6 @@ GroupWiseContact::GroupWiseContact( Kopete::Account* account, const QString &dn,
 
 GroupWiseContact::~GroupWiseContact()
 {
-	// This is necessary because otherwise the userDetailsManager 
-	// would not fetch details for this contact if they contact you
-	// again from off-contact-list.
-	if ( metaContact()->isTemporary() )
-		account()->client()->userDetailsManager()->removeContact( contactId() );
 }
 
 QString GroupWiseContact::dn() const
@@ -82,15 +78,15 @@ void GroupWiseContact::updateDetails( const ContactDetails & details )
 {
 	kDebug() ;
 	if ( !details.cn.isNull() )
-		setProperty( protocol()->propCN, details.cn );
+		setProperty( protocol()->propCN, QVariant(details.cn) );
 	if ( !details.dn.isNull() )
 		m_dn = details.dn;
 	if ( !details.givenName.isNull() )
-		setProperty( protocol()->propGivenName, details.givenName );
+		setProperty( protocol()->propGivenName, QVariant(details.givenName) );
 	if ( !details.surname.isNull() )
-		setProperty( protocol()->propLastName, details.surname );
+		setProperty( protocol()->propLastName, QVariant(details.surname) );
 	if ( !details.fullName.isNull() )
-		setProperty( protocol()->propFullName, details.fullName );
+		setProperty( protocol()->propFullName, QVariant(details.fullName) );
 	m_archiving = details.archive;
 	if ( !details.awayMessage.isNull() )
 		setStatusMessage( details.awayMessage );
@@ -99,15 +95,15 @@ void GroupWiseContact::updateDetails( const ContactDetails & details )
 	
 	// work phone number
 	if ( m_serverProperties.contains( "telephoneNumber" ) )
-		setProperty( protocol()->propPhoneWork, m_serverProperties.value( "telephoneNumber" ) );
+		setProperty( protocol()->propPhoneWork, QVariant(m_serverProperties.value( "telephoneNumber" )) );
 	
 	// mobile phone number
 	if ( m_serverProperties.contains( "mobile" ) )
-		setProperty( protocol()->propPhoneMobile, m_serverProperties.value( "mobile" ) );
+		setProperty( protocol()->propPhoneMobile, QVariant(m_serverProperties.value( "mobile" )) );
 	
 	// email
 	if ( m_serverProperties.contains( "Internet EMail Address" ) )
-		setProperty( protocol()->propEmail, m_serverProperties.value( "Internet EMail Address" ) );
+		setProperty( protocol()->propEmail, QVariant(m_serverProperties.value( "Internet EMail Address" )) );
 		
 	if ( details.status != GroupWise::Invalid )
 	{	
@@ -159,7 +155,7 @@ Kopete::ChatSession * GroupWiseContact::manager( Kopete::Contact::CanCreateFlags
 
 QList<KAction*> *GroupWiseContact::customContextMenuActions()
 {
-	QList<KAction *> * actionCollection = new QList<KAction *>;
+	QList<KAction *> * actions = new QList<KAction *>;
 
 	// Block/unblock contact
 	QString label = account()->isContactBlocked( m_dn ) ? i18n( "Unblock User" ) : i18n( "Block User" );
@@ -172,9 +168,12 @@ QList<KAction*> *GroupWiseContact::customContextMenuActions()
 		m_actionBlock->setText( label );
 	m_actionBlock->setEnabled( account()->isConnected() );
 
-	actionCollection->append( m_actionBlock );
+	actions->append( m_actionBlock );
+	// temporary action collection, used to apply Kiosk policy to the actions
+	KActionCollection tempCollection((QObject*)0);
+	tempCollection.addAction(QLatin1String("contactBlock"), m_actionBlock);
 
-	return actionCollection;
+	return actions;
 }
 
 void GroupWiseContact::slotUserInfo()
@@ -199,6 +198,7 @@ void GroupWiseContact::sendMessage( Kopete::Message &message )
 void GroupWiseContact::deleteContact()
 {
 	account()->deleteContact( this );
+	Kopete::Contact::deleteContact();
 }
 
 void GroupWiseContact::sync( unsigned int)
