@@ -1,12 +1,11 @@
-
 /*
     kircnumericreplies.cpp - IRC Client
 
-    Copyright (c) 2003      by Michel Hermier <michel.hermier@wanadoo.fr>
     Copyright (c) 2002      by Nick Betcher <nbetcher@kde.org>
     Copyright (c) 2003      by Jason Keirstead <jason@keirstead.org>
+    Copyright (c) 2003-2007 by Michel Hermier <michel.hermier@gmail.com>
 
-    Kopete    (c) 2002-2003 by the Kopete developers <kopete-devel@kde.org>
+    Kopete    (c) 2002-2007 by the Kopete developers <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -20,7 +19,10 @@
 
 #include "kircengine.h"
 
-#include <qtimer.h>
+#include <kdebug.h>
+#include <klocale.h>
+
+#include <qdatetime.h>
 
 using namespace KIRC;
 
@@ -42,16 +44,16 @@ void Engine::bindNumericReplies()
 	bind(252, this, SLOT(numericReply_252(KIRC::Message &)), 2, 2);
 	bind(253, this, SLOT(numericReply_253(KIRC::Message &)), 2, 2);
 	bind(254, this, SLOT(numericReply_254(KIRC::Message &)), 2, 2);
-	bind(255, this, SLOT(numericReply_255(KIRC::Message &)), 1, 1); // incomingConnectString
+	bind(255, this, SLOT(numericReply_255(KIRC::Message &)), 1, 1);
 
-	bind(263, this, SLOT(numericReply_263(KIRC::Message &))); // incomingServerLoadTooHigh
+	bind(263, this, SLOT(numericReply_263(KIRC::Message &)));
 	bind(265, this, SLOT(numericReply_265(KIRC::Message &)));
 	bind(266, this, SLOT(numericReply_266(KIRC::Message &)));
 
 	bind(301, this, SLOT(numericReply_301(KIRC::Message &)), 2, 2);
 	bind(303, this, SLOT(numericReply_303(KIRC::Message &)), 1, 1);
-	bind(305, this, SLOT(ignoreMessage(KIRC::Message &)), 0, 0 ); // You are no longer marked as away
-	bind(306, this, SLOT(ignoreMessage(KIRC::Message &)), 0, 0 ); // You are marked as away
+//	bind(305, this, SLOT(ignoreMessage(KIRC::Message &)), 0, 0 );
+//	bind(306, this, SLOT(ignoreMessage(KIRC::Message &)), 0, 0 );
 	bind(307, this, SLOT(numericReply_307(KIRC::Message &)), 1, 1);
 	bind(311, this, SLOT(numericReply_311(KIRC::Message &)), 5, 5);
 	bind(312, this, SLOT(numericReply_312(KIRC::Message &)), 3, 3);
@@ -62,13 +64,13 @@ void Engine::bindNumericReplies()
 	bind(318, this, SLOT(numericReply_318(KIRC::Message &)), 2, 2);
 	bind(319, this, SLOT(numericReply_319(KIRC::Message &)), 2, 2);
 	bind(320, this, SLOT(numericReply_320(KIRC::Message &)), 2, 2);
-	bind(321, this, SLOT(ignoreMessage(KIRC::Message &)), 0, 0 );
+//	bind(321, this, SLOT(ignoreMessage(KIRC::Message &)), 0, 0 );
 	bind(322, this, SLOT(numericReply_322(KIRC::Message &)), 3, 3);
 	bind(323, this, SLOT(numericReply_323(KIRC::Message &)), 1, 1);
 	bind(324, this, SLOT(numericReply_324(KIRC::Message &)), 2, 4);
 	bind(328, this, SLOT(numericReply_328(KIRC::Message &)), 2, 2);
 	bind(329, this, SLOT(numericReply_329(KIRC::Message &)), 3, 3);
-	bind(330, this, SLOT(ignoreMessage(KIRC::Message &)), 0, 0); // ???
+//	bind(330, this, SLOT(ignoreMessage(KIRC::Message &)), 3, 3); // ???
 	bind(331, this, SLOT(numericReply_331(KIRC::Message &)), 2, 2);
 	bind(332, this, SLOT(numericReply_332(KIRC::Message &)), 2, 2);
 	bind(333, this, SLOT(numericReply_333(KIRC::Message &)), 4, 4);
@@ -80,12 +82,12 @@ void Engine::bindNumericReplies()
 	bind(375, this, SLOT(ignoreMessage(KIRC::Message&)), 0, 0 );
 	bind(376, this, SLOT(ignoreMessage(KIRC::Message&)), 0, 0 );
 
-	bind(401, this, SLOT(numericReply_401(KIRC::Message &)), 2, 2); // incomingNoNickChan
-//	bind(404, this, SLOT(numericReply_404(KIRC::Message &)), 2, 2); // incomingCannotSendToChannel
-	bind(406, this, SLOT(numericReply_406(KIRC::Message &)), 2, 2); // incomingWasNoNick
+	bind(401, this, SLOT(numericReply_401(KIRC::Message &)), 2, 2);
+	bind(404, this, SLOT(numericReply_404(KIRC::Message &)), 2, 2);
+	bind(406, this, SLOT(numericReply_406(KIRC::Message &)), 2, 2);
 	bind(422, this, SLOT(numericReply_422(KIRC::Message &)), 1, 1);
 	bind(433, this, SLOT(numericReply_433(KIRC::Message &)), 2, 2);
-//	bind(442, this, SLOT(numericReply_442(KIRC::Message &)), 2, 2); // incomingCannotSendToChannel
+	bind(442, this, SLOT(numericReply_442(KIRC::Message &)), 2, 2);
 	bind(464, this, SLOT(numericReply_464(KIRC::Message &)), 1, 1);
 	bind(471, this, SLOT(numericReply_471(KIRC::Message &)), 2, 2);
 	bind(473, this, SLOT(numericReply_473(KIRC::Message &)), 2, 2);
@@ -93,7 +95,7 @@ void Engine::bindNumericReplies()
 	bind(475, this, SLOT(numericReply_475(KIRC::Message &)), 2, 2);
 
 	//Freenode seems to use this for a non-RFC compliant purpose, as does Unreal
-	bind(477, this, SLOT(emitSuffix(KIRC::Message&)),0,0);
+	bind(477, this, SLOT(receivedServerMessage(KIRC::Message&)),0,0);
 }
 
 /* 001: "Welcome to the Internet Relay Network <nick>!<user>@<host>"
@@ -101,31 +103,22 @@ void Engine::bindNumericReplies()
  */
 void Engine::numericReply_001(Message &msg)
 {
-	kdDebug(14121) << k_funcinfo << endl;
-
-	if (m_FailedNickOnLogin)
-	{
-		// this is if we had a "Nickname in use" message when connecting and we set another nick.
-		// This signal emits that the nick was accepted and we are now logged in
-		emit successfullyChangedNick(m_Nickname, m_PendingNick);
-		m_Nickname = m_PendingNick;
-		m_FailedNickOnLogin = false;
-	}
+	kDebug(14121) ;
 
 	/* At this point we are connected and the server is ready for us to being taking commands
 	 * although the MOTD comes *after* this.
 	 */
-	emitSuffix(msg);
+	receivedServerMessage(msg);
 
-	setStatus(Connected);
+	setConnectionState(Connected);
 }
 
 /* 002: ":Your host is <servername>, running version <ver>"
- * Gives information about the host. The given informations are close to 004.
+ * Gives information about the host. The given information are close to 004.
  */
 void Engine::numericReply_002(Message &msg)
 {
-	emitSuffix(msg);
+	receivedServerMessage(msg);
 }
 
 /* 003: "This server was created <date>"
@@ -134,7 +127,7 @@ void Engine::numericReply_002(Message &msg)
  */
 void Engine::numericReply_003(Message &msg)
 {
-	emitSuffix(msg);
+	receivedServerMessage(msg);
 }
 
 /* 004: "<servername> <version> <available user modes> <available channel modes>"
@@ -142,7 +135,7 @@ void Engine::numericReply_003(Message &msg)
  */
 void Engine::numericReply_004(Message &msg)
 {
-	emit incomingHostInfo(msg.arg(1),msg.arg(2),msg.arg(3),msg.arg(4));
+//	emit incomingHostInfo(msg.arg(1),msg.arg(2),msg.arg(3),msg.arg(4));
 }
 
 /* 005:
@@ -150,7 +143,7 @@ void Engine::numericReply_004(Message &msg)
  */
 void Engine::numericReply_005(Message &msg)
 {
-	emit incomingConnectString( msg.toString() );
+	receivedServerMessage(msg);
 }
 
 /* 250: ":Highest connection count: <integer> (<integer> clients)
@@ -160,7 +153,7 @@ void Engine::numericReply_005(Message &msg)
  */
 void Engine::numericReply_250(Message &msg)
 {
-	emit incomingConnectString( msg.suffix() );
+	receivedServerMessage(msg);
 }
 
 /* 251: ":There are <integer> users and <integer> services on <integer> servers"
@@ -168,14 +161,15 @@ void Engine::numericReply_250(Message &msg)
  */
 void Engine::numericReply_251(Message &msg)
 {
-	emit incomingConnectString( msg.suffix() );
+	receivedServerMessage(msg);
 }
+
 /* 252: "<integer> :operator(s) online"
  * Issues a number of operators on the server in the form of:
  */
 void Engine::numericReply_252(Message &msg)
 {
-	emit incomingConnectString( msg.arg(1) + ' ' + msg.suffix() );
+	receivedServerMessage(msg, i18n("There are %1 operators online.", msg.arg(1)));
 }
 
 /* 253: "<integer> :unknown connection(s)"
@@ -183,14 +177,15 @@ void Engine::numericReply_252(Message &msg)
  */
 void Engine::numericReply_253(Message &msg)
 {
-	emit incomingConnectString( msg.arg(1) + ' ' + msg.suffix() );
+	receivedServerMessage(msg, i18n("There are %1 unknown connections.", msg.arg(1)));
 }
 
-/* Tells how many total channels there are on this network in the form of:
- * "<integer> :channels formed" */
+/* 254: "<integer> :channels formed"
+ * Tells how many total channels there are on this network.
+ *  */
 void Engine::numericReply_254(Message &msg)
 {
-	emit incomingConnectString( msg.arg(1) + ' ' + msg.suffix() );
+	receivedServerMessage(msg, i18n("There have been %1 channels formed.", msg.arg(1)));
 }
 
 /* 255: ":I have <integer> clients and <integer> servers"
@@ -198,15 +193,15 @@ void Engine::numericReply_254(Message &msg)
  */
 void Engine::numericReply_255(Message &msg)
 {
-	emit incomingConnectString( msg.suffix() );
+	receivedServerMessage(msg);
 }
 
-/* 263:
+/* 263: "<command> :Please wait a while and try again."
  * Server is too busy.
  */
-void Engine::numericReply_263(Message &)
+void Engine::numericReply_263(Message &msg)
 {
-	emit incomingServerLoadTooHigh();
+	receivedServerMessage(msg, i18n("Server was too busy to execute %1.", msg.arg(1)));
 }
 
 /* 265: ":Current local  users: <integer>  Max: <integer>"
@@ -215,7 +210,7 @@ void Engine::numericReply_263(Message &)
  */
 void Engine::numericReply_265(Message &msg)
 {
-	emit incomingConnectString( msg.suffix() );
+	receivedServerMessage(msg);
 }
 
 /* 266: ":Current global users: <integer>  Max: <integer>"
@@ -223,47 +218,64 @@ void Engine::numericReply_265(Message &msg)
  */
 void Engine::numericReply_266(Message &msg)
 {
-	emit incomingConnectString( msg.suffix() );
+	receivedServerMessage(msg);
 }
 
 /* 301: "<nick> :<away message>"
  */
 void Engine::numericReply_301(Message &msg)
 {
-	emit incomingUserIsAway(Kopete::Message::unescape(msg.arg(1)), msg.suffix());
+/*
+	Entity entity = msg.entityFromArg(1);
+	entity->setAwayMessage(msg.suffix);
+	entity->setMode("+a");
+
+	receivedServerMessage(msg);
+*/
 }
 
 /* 303: ":*1<nick> *(" " <nick> )"
  */
 void Engine::numericReply_303(Message &msg)
 {
+/*
 	QStringList nicks = QStringList::split(QRegExp(QChar(' ')), msg.suffix());
 	for(QStringList::Iterator it = nicks.begin(); it != nicks.end(); ++it)
 	{
-		if (!(*it).stripWhiteSpace().isEmpty())
-			emit incomingUserOnline(Kopete::Message::unescape(*it));
+		if (!(*it).trimmed().isEmpty())
+			emit incomingUserOnline(*it);
 	}
+*/
 }
 
 /* 305: ":You are no longer marked as being away"
  */
-// void Engine::numericReply_305(Message &msg)
-// {
-// }
+void Engine::numericReply_305(Message &msg)
+{
+/*
+	EntityPtr self = this->self();
+	self->setAwayMessage(QString());
+//	self->setModes("-a");
+	receivedServerMessage(msg, i18n("You are no longer marked as being away."));
+*/
+}
 
 
 /* 306: ":You have been marked as being away"
  */
-// void Engine::numericReply_306(Message &msg)
-// {
-// }
+void Engine::numericReply_306(Message &msg)
+{
+	EntityPtr self = this->self();
+//	self->setModes("+a");
+	receivedServerMessage(msg, i18n("You have been marked as being away."));
+}
 
 /* 307: ":is a registered nick"
  * DALNET: Indicates that this user is identified with NICSERV.
  */
-void Engine::numericReply_307(Message & /*msg*/)
+void Engine::numericReply_307(Message &msg)
 {
-//	emit incomingWhoiIsUserNickIsRegistered(Kopete::Message::unescape(msg.arg(1)));
+	receivedServerMessage(msg, i18n("%1 is a registered nick.", msg.arg(1)));
 }
 
 /* 311: "<nick> <user> <host> * :<real name>"
@@ -271,7 +283,7 @@ void Engine::numericReply_307(Message & /*msg*/)
  */
 void Engine::numericReply_311(Message &msg)
 {
-	emit incomingWhoIsUser(Kopete::Message::unescape(msg.arg(1)), msg.arg(2), msg.arg(3), msg.suffix());
+//	emit incomingWhoIsUser(msg.arg(1), msg.arg(2), msg.arg(3), msg.suffix());
 }
 
 /* 312: "<nick> <server> :<server info>"
@@ -279,14 +291,15 @@ void Engine::numericReply_311(Message &msg)
  */
 void Engine::numericReply_312(Message &msg)
 {
-	emit incomingWhoIsServer(Kopete::Message::unescape(msg.arg(1)), msg.arg(2), msg.suffix());
+//	emit incomingWhoIsServer(msg.arg(1), msg.arg(2), msg.suffix());
 }
 
 /* 313: "<nick> :is an IRC operator"
  * Show info about an operator (part of a /whois).
  */
-void Engine::numericReply_313(Message & /*msg*/)
+void Engine::numericReply_313(Message &msg)
 {
+	receivedServerMessage(msg, i18n("%1 is an IRC operator.", msg.arg(1)));
 }
 
 /* 314: "<nick> <user> <host> * :<real name>"
@@ -294,23 +307,28 @@ void Engine::numericReply_313(Message & /*msg*/)
  */
 void Engine::numericReply_314(Message &msg)
 {
-	emit incomingWhoWasUser(Kopete::Message::unescape(msg.arg(1)), msg.arg(2), msg.arg(3), msg.suffix());
+//	emit incomingWhoWasUser(msg.arg(1), msg.arg(2), msg.arg(3), msg.suffix());
 }
 
+/* 315: "<name> :End of WHO list"
+ * End of WHO list.
+ */
 void Engine::numericReply_315(Message &msg)
 {
-	emit incomingEndOfWho(Kopete::Message::unescape(msg.arg(1)));
+	receivedServerMessage(msg);
 }
 
+/* RFC say: "<nick> <integer> :seconds idle"
+ * Some servers say: "<nick> <integer> <integer> :seconds idle, signon time"
+ * Show info about someone who is idle (part of a /whois) in the form of:
+ */
 void Engine::numericReply_317(Message &msg)
 {
-	/* RFC say: "<nick> <integer> :seconds idle"
-	 * Some servers say: "<nick> <integer> <integer> :seconds idle, signon time"
-	 * Show info about someone who is idle (part of a /whois) in the form of:
-	 */
-	emit incomingWhoIsIdle(Kopete::Message::unescape(msg.arg(1)), msg.arg(2).toULong());
+/*
+	emit incomingWhoIsIdle(msg.arg(1), msg.arg(2).toULong());
 	if (msg.argsSize()==4)
-		emit incomingSignOnTime(Kopete::Message::unescape(msg.arg(1)),msg.arg(3).toULong());
+		emit incomingSignOnTime(msg.arg(1),msg.arg(3).toULong());
+*/
 }
 
 /* 318: "<nick>{<space><realname>} :End of /WHOIS list"
@@ -318,15 +336,15 @@ void Engine::numericReply_317(Message &msg)
  */
 void Engine::numericReply_318(Message &msg)
 {
-	emit incomingEndOfWhois(Kopete::Message::unescape(msg.arg(1)));
+	emit receivedServerMessage(msg);
 }
 
+/* 319: "<nick> :{[@|+]<channel><space>}"
+ * Show info a channel a user is logged in (part of a /whois) in the form of:
+ */
 void Engine::numericReply_319(Message &msg)
 {
-	/* Show info a channel a user is logged in (part of a /whois) in the form of:
-	 * "<nick> :{[@|+]<channel><space>}"
-	 */
-	emit incomingWhoIsChannels(Kopete::Message::unescape(msg.arg(1)), msg.suffix());
+//	emit incomingWhoIsChannels(msg.arg(1), msg.suffix());
 }
 
 /* 320:
@@ -334,7 +352,7 @@ void Engine::numericReply_319(Message &msg)
  */
 void Engine::numericReply_320(Message &msg)
 {
-	emit incomingWhoIsIdentified(Kopete::Message::unescape(msg.arg(1)));
+//	emit incomingWhoIsIdentified(msg.arg(1));
 }
 
 /* 321: "<channel> :Users  Name" ("Channel :Users  Name")
@@ -347,46 +365,43 @@ void Engine::numericReply_320(Message &msg)
  */
 void Engine::numericReply_322(Message &msg)
 {
-	//kdDebug(14120) << k_funcinfo << "Listed " << msg.arg(1) << endl;
-
-	emit incomingListedChan(Kopete::Message::unescape(msg.arg(1)), msg.arg(2).toUInt(), msg.suffix());
+//	emit incomingListedChan(msg.arg(1), msg.arg(2).toUInt(), msg.suffix());
 }
 
 /* 323: ":End of LIST"
  * End of the LIST command.
  */
-void Engine::numericReply_323(Message &)
+void Engine::numericReply_323(Message &msg)
 {
-	emit incomingEndOfList();
+	emit receivedServerMessage(msg);
 }
 
 /* 324: "<channel> <mode> <mode params>"
  */
 void Engine::numericReply_324(Message &msg)
 {
-	emit incomingChannelMode(Kopete::Message::unescape(msg.arg(1)), msg.arg(2), msg.arg(3));
+//	emit incomingChannelMode(msg.arg(1), msg.arg(2), msg.arg(3));
 }
 
 /* 328: "<channel> <mode> <mode params>"
  */
 void Engine::numericReply_328(Message &msg)
 {
-	kdDebug(14120) << k_funcinfo << endl;
-	emit incomingChannelHomePage(Kopete::Message::unescape(msg.arg(1)), msg.suffix());
+//	emit incomingChannelHomePage(msg.arg(1), msg.suffix());
 }
 
 /* 329: "%s %lu"
  * NOTE: What is the meaning of this arguments. DAL-ircd say it's a RPL_CREATIONTIME
  * NOT IN RFC1459 NOR RFC2812
  */
-void Engine::numericReply_329( Message &)
+void Engine::numericReply_329( Message & )
 {
 }
 
 /* 331: "<channel> :No topic is set"
  * Gives the existing topic for a channel after a join.
  */
-void Engine::numericReply_331( Message &)
+void Engine::numericReply_331( Message & )
 {
 //	emit incomingExistingTopic(msg.arg(1), suffix);
 }
@@ -394,9 +409,9 @@ void Engine::numericReply_331( Message &)
 /* 332: "<channel> :<topic>"
  * Gives the existing topic for a channel after a join.
  */
-void Engine::numericReply_332(Message &msg)
+void Engine::numericReply_332( Message &msg )
 {
-	emit incomingExistingTopic(Kopete::Message::unescape(msg.arg(1)), msg.suffix());
+//	emit incomingExistingTopic(msg.arg(1), msg.suffix());
 }
 
 /* 333:
@@ -404,33 +419,33 @@ void Engine::numericReply_332(Message &msg)
  */
 void Engine::numericReply_333( Message &msg )
 {
-	kdDebug(14120) << k_funcinfo << endl;
+/*
 	QDateTime d;
 	d.setTime_t( msg.arg(3).toLong() );
-	emit incomingTopicUser( Kopete::Message::unescape(msg.arg(1)), Kopete::Message::unescape(msg.arg(2)), d );
+	emit incomingTopicUser(msg.arg(1), msg.arg(2), d );
+*/
 }
 
 /* 352:
  * WHO Reply
- * 
- * "<channel> <user> <host> <server> <nick> ("H" / "G") ["*"] [("@" / "+")] :<hopcount> <real name>"
- *
- * :efnet.cs.hut.fi 352 userNick #foobar username some.host.name efnet.cs.hut.fi someNick H :0 foobar
- * :efnet.cs.hut.fi 352 userNick #foobar ~fooobar other.hostname irc.dkom.at anotherNick G+ :3 Unknown
  */
 void Engine::numericReply_352(Message &msg)
 {
+/*
+	QStringList suffix = QStringList::split( ' ', msg.suffix() );
+
 	emit incomingWhoReply(
-		Kopete::Message::unescape(msg.arg(5)),       // nick name
-		Kopete::Message::unescape(msg.arg(1)),       // channel name
-		msg.arg(2),                                  // user name
-		msg.arg(3),                                  // host name
-		msg.arg(4),                                  // server name
-		msg.arg(6)[0] != 'H',                        // G=away (true), H=not away (false)
-		msg.arg(7),                                  // @ (op), + (voiced)
-		msg.suffix().section(' ', 0, 1 ).toUInt(),   // hopcount
-		msg.suffix().section(' ', 1 )                // real name
+		msg.arg(5),
+		msg.arg(1),
+		msg.arg(2),
+		msg.arg(3),
+		msg.arg(4),
+		msg.arg(6)[0] != 'H',
+		msg.arg(7),
+		msg.suffix().section(' ', 0, 1 ).toUInt(),
+		msg.suffix().section(' ', 1 )
 	);
+*/
 }
 
 
@@ -439,7 +454,7 @@ void Engine::numericReply_352(Message &msg)
  */
 void Engine::numericReply_353(Message &msg)
 {
-	emit incomingNamesList(Kopete::Message::unescape(msg.arg(2)), QStringList::split(' ', msg.suffix()));
+//	emit incomingNamesList(msg.arg(2), QStringList::split(' ', msg.suffix()));
 }
 
 /* 366: "<channel> :End of NAMES list"
@@ -447,14 +462,15 @@ void Engine::numericReply_353(Message &msg)
  */
 void Engine::numericReply_366(Message &msg)
 {
-	emit incomingEndOfNames(msg.arg(1));
+	emit receivedServerMessage(msg);
 }
 
-/* 369:
+/* 369: "<nick> :End of WHOWAS"
  * End of WHOWAS Request
  */
-void Engine::numericReply_369(Message & /*msg*/)
+void Engine::numericReply_369(Message &msg)
 {
+	emit receivedServerMessage(msg);
 }
 
 /* 372: ":- <text>"
@@ -462,7 +478,10 @@ void Engine::numericReply_369(Message & /*msg*/)
  */
 void Engine::numericReply_372(Message &msg)
 {
-	emit incomingMotd(msg.suffix());
+#ifdef __GNUC__
+	#warning FIXME remove the "- " in front.
+#endif
+	receivedServerMessage(msg);
 }
 
 /* 375: ":- <server> Message of the day - "
@@ -472,6 +491,10 @@ void Engine::numericReply_372(Message &msg)
 /* 376: ":End of MOTD command"
  * End of the motd.
  */
+void Engine::numericReply_376(Message &msg)
+{
+	receivedServerMessage(msg);
+}
 
 /* 401: "<nickname> :No such nick/channel"
  * Gives a signal to indicate that the command issued failed because the person/channel not being on IRC.
@@ -479,7 +502,15 @@ void Engine::numericReply_372(Message &msg)
  */
 void Engine::numericReply_401(Message &msg)
 {
-	emit incomingNoSuchNickname( Kopete::Message::unescape(msg.arg(1)) );
+//	i18n("The channel \"%1\" does not exist").arg(nick)
+//	i18n("The nickname \"%1\" does not exist").arg(nick)
+}
+
+/* 404: "<channel name> :Cannot send to channel"
+ */
+void Engine::numericReply_404(Message &msg)
+{
+	receivedServerMessage(msg, i18n("You cannot send message to channel %1.", msg.arg(1)));
 }
 
 /* 406: "<nickname> :There was no such nickname"
@@ -487,7 +518,11 @@ void Engine::numericReply_401(Message &msg)
  */
 void Engine::numericReply_406(Message &msg)
 {
-	emit incomingNoSuchNickname( Kopete::Message::unescape(msg.arg(1)) );
+#ifdef __GNUC__
+	#warning FIXME 406 MEANS *NEVER*, unlike 401
+#endif
+//	i18n("The channel \"%1\" does not exist").arg(nick)
+//	i18n("The nickname \"%1\" does not exist").arg(nick)
 }
 
 /* 422: ":MOTD File is missing"
@@ -496,7 +531,7 @@ void Engine::numericReply_406(Message &msg)
  */
 void Engine::numericReply_422(Message &msg)
 {
-	emit incomingMotd(msg.suffix());
+	receivedServerMessage(msg);
 }
 
 /* 433: "<nick> :Nickname is already in use"
@@ -504,20 +539,27 @@ void Engine::numericReply_422(Message &msg)
  */
 void Engine::numericReply_433(Message &msg)
 {
-	if(m_status == Authentifying)
+//	if(m_status == Authentifying)
 	{
 		// This tells us that our nickname is, but we aren't logged in.
 		// This differs because the server won't send us a response back telling us our nick changed
 		// (since we aren't logged in).
-		m_FailedNickOnLogin = true;
-		emit incomingFailedNickOnLogin(Kopete::Message::unescape(msg.arg(1)));
+//		m_FailedNickOnLogin = true;
+//		emit incomingFailedNickOnLogin(msg.arg(1));
 	}
-	else
-	{
+//	else
+//	{
 		// And this is the signal for if someone is trying to use the /nick command or such when already logged in,
 		// but it's already in use
-		emit incomingNickInUse(Kopete::Message::unescape(msg.arg(1)));
-	}
+//		emit incomingNickInUse(msg.arg(1));
+//	}
+}
+
+/* 442: "<channel> :You're not on that channel"
+ */
+void Engine::numericReply_442(Message &msg)
+{
+	receivedServerMessage(msg, i18n("You are not on channel %1.", msg.arg(1)));
 }
 
 /* 464: ":Password Incorrect"
@@ -526,45 +568,81 @@ void Engine::numericReply_433(Message &msg)
 void Engine::numericReply_464(Message &/*msg*/)
 {
 	/* Server need pass.. Call disconnect*/
-	emit incomingFailedServerPassword();
+//	emit incomingFailedServerPassword();
 }
 
-/* 471:
+/* 465: ":You are banned from this server"
+ */
+
+/* 471: "<channel> :Cannot join channel (+l)"
  * Channel is Full
  */
 void Engine::numericReply_471(Message &msg)
 {
-	emit incomingFailedChanFull(Kopete::Message::unescape(msg.arg(1)));
+	receivedServerMessage(msg, i18n("Cannot join %1, channel is full.", msg.arg(1)) );
 }
 
-/* 473:
+/* 472: "<char> :is unknown mode char to me for <channel>"
+ */
+
+/* 473: "<channel> :Cannot join channel (+i)"
  * Invite Only.
  */
 void Engine::numericReply_473(Message &msg)
 {
-	emit incomingFailedChanInvite(Kopete::Message::unescape(msg.arg(1)));
+	receivedServerMessage(msg, i18n("Cannot join %1, channel is invite only.", msg.arg(1)) );
 }
 
-/* 474:
+/* 474: "<channel> :Cannot join channel (+b)"
  * Banned.
  */
 void Engine::numericReply_474(Message &msg)
 {
-	emit incomingFailedChanBanned(Kopete::Message::unescape(msg.arg(1)));
+	receivedServerMessage(msg, i18n("Cannot join %1, you are banned from that channel.", msg.arg(1)) );
 }
 
-/* 475:
+/* 475: "<channel> :Cannot join channel (+k)"
  * Wrong Chan-key.
  */
 void Engine::numericReply_475(Message &msg)
 {
-	emit incomingFailedChankey(Kopete::Message::unescape(msg.arg(1)));
+	receivedServerMessage(msg, i18n("Cannot join %1, wrong channel key was given.", msg.arg(1)) );
 }
 
-/* 477: "<channel> :You need a registered nick to join that channel."
- * Available on DALNET servers only ?
+/* 476: "<channel> :Bad Channel Mask"
+ */
+
+/* 477: "<channel> :Channel doesn't support modes" RFC-2812
+ * 477: "<channel> :You need a registered nick to join that channel." DALNET
  */
 // void Engine::numericReply_477(Message &msg)
 // {
 // 	emit incomingChannelNeedRegistration(msg.arg(2), msg.suffix());
 // }
+
+/* 478: "<channel> <char> :Channel list is full"
+ */
+
+/* 481: ":Permission Denied- You're not an IRC operator"
+ */
+
+/* 482: "<channel> :You're not channel operator"
+ */
+
+/* 483: ":You can't kill a server!"
+ */
+
+/* 484: ":Your connection is restricted!"
+ */
+
+/* 485: ":You're not the original channel operator"
+ */
+
+/* 491: ":No O-lines for your host"
+ */
+
+/* 501: ":Unknown MODE flag"
+ */
+
+/* 502: ":Cannot change mode for other users"
+ */
