@@ -52,6 +52,7 @@
 JabberBaseContact::JabberBaseContact (const XMPP::RosterItem &rosterItem, Kopete::Account *account, Kopete::MetaContact * mc, const QString &legacyId)
 	: Kopete::Contact (account, legacyId.isEmpty() ? rosterItem.jid().full() : legacyId , mc )
 {
+	mSendsDeliveredEvent = false;
 	setDontSync ( false );
 	
 	JabberTransport *t=transport();
@@ -519,7 +520,7 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 	removeProperty( protocol()->propHomePostalCode );
 	removeProperty( protocol()->propHomeCountry );
 
-	for(XMPP::VCard::AddressList::const_iterator it = vCard.addressList().begin(); it != vCard.addressList().end(); it++)
+	for(XMPP::VCard::AddressList::const_iterator it = vCard.addressList().begin(); it != vCard.addressList().end(); ++it)
 	{
 		XMPP::VCard::Address address = (*it);
 
@@ -668,7 +669,6 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 			setProperty( protocol()->propPhoto, entry.path );
 		}
 	}
-
 }
 
 
