@@ -49,6 +49,8 @@ JabberChatSession::JabberChatSession ( JabberProtocol *protocol, const JabberBas
 											 : Kopete::ChatSession ( user, others, protocol )
 {
 	kDebug ( JABBER_DEBUG_GLOBAL ) << "New message manager for " << user->contactId ();
+	
+	setComponentData(protocol->componentData());
 
 	// make sure Kopete knows about this instance
 	Kopete::ChatSessionManager::self()->registerChatSession ( this );
@@ -67,32 +69,60 @@ JabberChatSession::JabberChatSession ( JabberProtocol *protocol, const JabberBas
 	mResource = jid.resource().isEmpty () ? resource : jid.resource ();
 	slotUpdateDisplayName ();
 
-#ifdef SUPPORT_JINGLE
-	KAction *jabber_voicecall = new KAction( i18n("Voice call" ), "voicecall", 0, members().getFirst(), SLOT(voiceCall ()), actionCollection(), "jabber_voicecall" );
-
+#ifdef JINGLE_SUPPORT
+	KAction *jingleSessionGui = new KAction(i18n("Show audio calls"), members().first());
+	connect(jingleSessionGui, SIGNAL(triggered(bool)), SLOT (slotJingleSessionGui() ));
 	setComponentData(protocol->componentData());
-	jabber_voicecall->setEnabled( false );
-
 	
-	Kopete::ContactPtrList chatMembers = members ();
-	if ( chatMembers.first () )
+	KAction *jingleSession = new KAction(i18n("Start audio call"), members().first());
+	connect(jingleSession, SIGNAL(triggered(bool)), SLOT (slotJingleSession() ));
+	setComponentData(protocol->componentData());
+	
+	Kopete::ContactPtrList chatMembers = members();
+	if (chatMembers.first())
 	{
-		// Check if the current contact support Voice calls, also honor lock by default.
-		// FIXME: we should use the active ressource
-		JabberResource *bestResource = account()->resourcePool()->  bestJabberResource( static_cast<JabberBaseContact*>(chatMembers.first())->rosterItem().jid() );
-		if( bestResource && bestResource->features().canVoice() )
+		JabberResource *bestResource = account()->resourcePool()->bestJabberResource( static_cast<JabberBaseContact*>(chatMembers.first())->rosterItem().jid() );
+		if (bestResource)
 		{
-			jabber_voicecall->setEnabled( true );
+			jingleSessionGui->setEnabled( bestResource->features().canJingle() );
+			jingleSession->setEnabled( bestResource->features().canJingle() );
+		}
+		else
+		{
+			jingleSessionGui->setEnabled(false);
+			jingleSession->setEnabled(false);
 		}
 	}
+	
+
+	/*KAction *jingleaudiocall = new KAction(i18n("Jingle Audio call" ), members().first());
+	connect(jingleaudiocall, SIGNAL(triggered(bool)), SLOT (slotJingleAudioCall() ));
+	setComponentData(protocol->componentData());
+	jingleaudiocall->setEnabled( false );
+
+	KAction *jinglevideocall = new KAction(i18n("Jingle Video call" ), members().first());
+	connect(jinglevideocall, SIGNAL(triggered(bool)), SLOT (slotJingleVideoCall() ));
+	setComponentData(protocol->componentData());
+	jinglevideocall->setEnabled( false );*/
+	
+	//Kopete::ContactPtrList chatMembers = members ();
+	//if ( chatMembers.first () )
+	//{
+		// Check if the current contact support Audio calls, also honor lock by default.
+		// FIXME: we should use the active ressource
+		//jingleaudiocall->setEnabled( bestResource->features().canJingleAudio() );
+		//jinglevideocall->setEnabled( bestResource->features().canJingleVideo() );
+	//}
+	
+	//FIXME : Toolbar does not show any action (either for MSN or XMPP)
+	//	  It should be corrected in trunk.
+	//actionCollection()->addAction( "jabberJingleaudiocall", jingleaudiocall );
+	//actionCollection()->addAction( "jabberJinglevideocall", jinglevideocall );
+	actionCollection()->addAction( "jingleSession", jingleSession );
+	actionCollection()->addAction( "jingleSessionsGui", jingleSessionGui );
 
 #endif
 
-	KAction* sendFile = new KAction( this );
-	sendFile->setIcon( KIcon( "attach" ) );
-	sendFile->setText( i18n( "Send File" ) );
-	QObject::connect(sendFile, SIGNAL( triggered( bool ) ), SLOT( slotSendFile() ));
-	actionCollection()->addAction( "jabberSendFile", sendFile );
 	setXMLFile("jabberchatui.rc");
 
 }
@@ -329,6 +359,7 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
 
 		jabberMessage.setTo ( toJid );
 
+		jabberMessage.setId( QString::number( message.id() ) );
 		jabberMessage.setSubject ( message.subject () );
 		jabberMessage.setTimeStamp ( message.timestamp () );
 
@@ -371,7 +402,7 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
 					//  see Bug 121627
 					// Anyway, theses client that do like that are *WRONG*  considreded the example of jep-71 where there are lot of
 					// linebreak that are not interpreted.  - Olivier 2006-31-03
-					xhtmlBody.replace('\n',"");
+					xhtmlBody.remove('\n');
 					
 					//&nbsp; is not a valid XML entity
 					xhtmlBody.replace("&nbsp;" , "&#160;");
@@ -412,6 +443,9 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
         // send the message
 		account()->client()->sendMessage ( jabberMessage );
 
+		if ( recipient->sendsDeliveredEvent() )
+			message.setState( Kopete::Message::StateSending );
+
 		// append the message to the manager
 		Kopete::ChatSession::appendMessage ( message );
 
@@ -429,11 +463,39 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
 
 }
 
- void JabberChatSession::slotSendFile()
-      {
-              QList<Kopete::Contact*>contacts = members();
-              static_cast<JabberContact *>(contacts.first())->sendFile();
-      }
+void JabberChatSession::slotSendFile()
+{
+	QList<Kopete::Contact*>contacts = members();
+	static_cast<JabberContact *>(contacts.first())->sendFile();
+}
+
+
+#ifdef JINGLE_SUPPORT
+void JabberChatSession::slotJingleAudioCall()
+{
+	QList<Kopete::Contact*> contacts = members();
+	static_cast<JabberContact *>(contacts.first())->startJingleAudioCall();
+}
+
+void JabberChatSession::slotJingleVideoCall()
+{
+	QList<Kopete::Contact*> contacts = members();
+	static_cast<JabberContact *>(contacts.first())->startJingleVideoCall();
+}
+
+void JabberChatSession::slotJingleSessionGui()
+{
+	QList<Kopete::Contact*> contacts = members();
+	static_cast<JabberContact *>(contacts.first())->showSessionsGui();
+}
+
+void JabberChatSession::slotJingleSession()
+{
+	QList<Kopete::Contact*> contacts = members();
+	static_cast<JabberContact *>(contacts.first())->startJingleSession();
+}
+
+#endif
 
 #include "jabberchatsession.moc"
 
