@@ -19,19 +19,19 @@
 #ifndef JABBERPROTOCOL_H
 #define JABBERPROTOCOL_H
 
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qmap.h>
-#include <qpixmap.h>
-#include <qmovie.h>
-#include <kaction.h>
-#include <kpopupmenu.h>
 
-#include "kopetecontact.h"
-#include "kopetecontactproperty.h"
-#include "kopetemetacontact.h"
+#include <QMap>
+
+#include "kopeteprotocol.h"
+#include "kopetemimetypehandler.h"
+#include "kopeteproperty.h"
 #include "kopeteonlinestatus.h"
-#include "addcontactpage.h"
+
+class AddContactPage;
+namespace Kopete {
+	class Contact;
+	class MetaContact;
+}
 
 #define JABBER_DEBUG_GLOBAL		14130
 #define JABBER_DEBUG_PROTOCOL	14131
@@ -39,22 +39,20 @@
 namespace XMPP
 {
 	class Resource;
+	class Status;
 }
 
-class JabberContact;
-class dlgJabberStatus;
-class dlgJabberSendRaw;
+class JabberCapabilitiesManager;
 
-class JabberProtocol:public Kopete::Protocol
+class JabberProtocol:public Kopete::Protocol , private Kopete::MimeTypeHandler
 {
 	Q_OBJECT
 
 public:
-
 	/**
 	 * Object constructor and destructor
 	 */
-	 JabberProtocol (QObject * parent, const char *name, const QStringList &);
+	 JabberProtocol (QObject * parent, const QVariantList &);
 	 ~JabberProtocol ();
 
 	/**
@@ -82,45 +80,45 @@ public:
 	const Kopete::OnlineStatus JabberKOSInvisible;
 	const Kopete::OnlineStatus JabberKOSConnecting;
 
-	const Kopete::ContactPropertyTmpl propLastSeen;
-	const Kopete::ContactPropertyTmpl propAwayMessage;
-	const Kopete::ContactPropertyTmpl propFirstName;
-	const Kopete::ContactPropertyTmpl propLastName;
-	const Kopete::ContactPropertyTmpl propFullName;
-	const Kopete::ContactPropertyTmpl propEmailAddress;
-	const Kopete::ContactPropertyTmpl propPrivatePhone;
-	const Kopete::ContactPropertyTmpl propPrivateMobilePhone;
-	const Kopete::ContactPropertyTmpl propWorkPhone;
-	const Kopete::ContactPropertyTmpl propWorkMobilePhone;
-	const Kopete::ContactPropertyTmpl propNickName;
-	const Kopete::ContactPropertyTmpl propSubscriptionStatus;
-	const Kopete::ContactPropertyTmpl propAuthorizationStatus;
-	const Kopete::ContactPropertyTmpl propAvailableResources;
-	const Kopete::ContactPropertyTmpl propVCardCacheTimeStamp;
+	const Kopete::PropertyTmpl propLastSeen;
+	const Kopete::PropertyTmpl propFirstName;
+	const Kopete::PropertyTmpl propLastName;
+	const Kopete::PropertyTmpl propFullName;
+	const Kopete::PropertyTmpl propEmailAddress;
+	const Kopete::PropertyTmpl propPrivatePhone;
+	const Kopete::PropertyTmpl propPrivateMobilePhone;
+	const Kopete::PropertyTmpl propWorkPhone;
+	const Kopete::PropertyTmpl propWorkMobilePhone;
+	const Kopete::PropertyTmpl propNickName;
+	const Kopete::PropertyTmpl propSubscriptionStatus;
+	const Kopete::PropertyTmpl propAuthorizationStatus;
+	const Kopete::PropertyTmpl propAvailableResources;
+	const Kopete::PropertyTmpl propVCardCacheTimeStamp;
+	const Kopete::PropertyTmpl propPhoto;
 	// extra properties to match with vCard
-	const Kopete::ContactPropertyTmpl propJid;
-	const Kopete::ContactPropertyTmpl propBirthday;
-	const Kopete::ContactPropertyTmpl propTimezone;
-	const Kopete::ContactPropertyTmpl propHomepage;
-	const Kopete::ContactPropertyTmpl propCompanyName;
-	const Kopete::ContactPropertyTmpl propCompanyDepartement;
-	const Kopete::ContactPropertyTmpl propCompanyPosition;
-	const Kopete::ContactPropertyTmpl propCompanyRole;
-	const Kopete::ContactPropertyTmpl propWorkStreet;
-	const Kopete::ContactPropertyTmpl propWorkExtAddr;
-	const Kopete::ContactPropertyTmpl propWorkPOBox;
-	const Kopete::ContactPropertyTmpl propWorkCity;
-	const Kopete::ContactPropertyTmpl propWorkPostalCode;
-	const Kopete::ContactPropertyTmpl propWorkCountry;
-	const Kopete::ContactPropertyTmpl propWorkEmailAddress;
-	const Kopete::ContactPropertyTmpl propHomeStreet;
-	const Kopete::ContactPropertyTmpl propHomeExtAddr;
-	const Kopete::ContactPropertyTmpl propHomePOBox;
-	const Kopete::ContactPropertyTmpl propHomeCity;
-	const Kopete::ContactPropertyTmpl propHomePostalCode;
-	const Kopete::ContactPropertyTmpl propHomeCountry;
-	const Kopete::ContactPropertyTmpl propPhoneFax;
-	const Kopete::ContactPropertyTmpl propAbout;
+	const Kopete::PropertyTmpl propJid;
+	const Kopete::PropertyTmpl propBirthday;
+	const Kopete::PropertyTmpl propTimezone;
+	const Kopete::PropertyTmpl propHomepage;
+	const Kopete::PropertyTmpl propCompanyName;
+	const Kopete::PropertyTmpl propCompanyDepartement;
+	const Kopete::PropertyTmpl propCompanyPosition;
+	const Kopete::PropertyTmpl propCompanyRole;
+	const Kopete::PropertyTmpl propWorkStreet;
+	const Kopete::PropertyTmpl propWorkExtAddr;
+	const Kopete::PropertyTmpl propWorkPOBox;
+	const Kopete::PropertyTmpl propWorkCity;
+	const Kopete::PropertyTmpl propWorkPostalCode;
+	const Kopete::PropertyTmpl propWorkCountry;
+	const Kopete::PropertyTmpl propWorkEmailAddress;
+	const Kopete::PropertyTmpl propHomeStreet;
+	const Kopete::PropertyTmpl propHomeExtAddr;
+	const Kopete::PropertyTmpl propHomePOBox;
+	const Kopete::PropertyTmpl propHomeCity;
+	const Kopete::PropertyTmpl propHomePostalCode;
+	const Kopete::PropertyTmpl propHomeCountry;
+	const Kopete::PropertyTmpl propPhoneFax;
+	const Kopete::PropertyTmpl propAbout;
 
 	/**
 	 * This returns our protocol instance
@@ -136,6 +134,21 @@ public:
 	 * Convert an XMPP::Resource status to a Kopete::OnlineStatus
 	 */
 	Kopete::OnlineStatus resourceToKOS ( const XMPP::Resource &resource );
+	
+	/**
+	 * Convert an online status to a  XMPP::Status
+	 */
+	XMPP::Status kosToStatus( const Kopete::OnlineStatus & status, const QString& message=QString() );
+
+	/**
+	 * Return the Entity Capabilities(JEP-0115) manager instance.
+	 */
+	JabberCapabilitiesManager *capabilitiesManager();
+	
+	/**
+	 * inherited from Kopete::MimeTypeHandler
+	 */
+	virtual void handleURL( const KUrl & url ) const;
 
 private:
 	/*
@@ -143,6 +156,11 @@ private:
 	 */
 	static JabberProtocol *protocolInstance;
 
+	/**
+	 * Unique Instance of the Entity Capabilities(JEP-0115) manager for Kopete Jabber plugin.
+	 */
+	JabberCapabilitiesManager *capsManager;
+	
 };
 
 #endif
