@@ -1,9 +1,9 @@
 #ifndef TESTDEBUG_H
 #define TESTDEBUG_H
 
-#include<qdom.h>
+#include <qdom.h>
 
-class TD
+class IRIS_EXPORT TD
 {
 public:
 	TD();
