@@ -2,8 +2,9 @@
     msnswitchboardsocket.h - switch board connection socket
 
     Copyright (c) 2002      by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002-2006 by Olivier Goffart        <ogoffart@ kde.org>
-    Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
+    Copyright (c) 2002-2006 by Olivier Goffart        <ogoffart@kde.org>
+
+	Kopete    (c) 2002-2007 by the Kopete developers  <kopete-devel@kde.org>
 
     Portions of this code are taken from KMerlin,
               (c) 2001 by Olaf Lueg              <olueg@olsd.de>
@@ -22,8 +23,10 @@
 #define MSNSWITCHBOARDSOCKET_H
 
 #include <qobject.h>
-#include <qstrlist.h>
-#include <qvaluevector.h>
+#include <QStringList>
+#include <QVector>
+#include <QList>
+#include <QPair>
 
 #include <kstringhandler.h>
 
@@ -33,14 +36,13 @@ namespace Kopete { class Message; }
 class MSNAccount;
 class QTimer;
 
-class MSNP2PDisplatcher;
-class KTempFile;
+class KTemporaryFile;
 
 namespace P2P { class Dispatcher; }
 
 #include "dispatcher.h"
 
-class KOPETE_EXPORT MSNSwitchBoardSocket : public MSNSocket
+class KOPETE_MSN_SHARED_EXPORT MSNSwitchBoardSocket : public MSNSocket
 {
 	Q_OBJECT
 
@@ -58,7 +60,7 @@ private:
 	QString m_myHandle; // our handle
 
 	// contains the handle of the last person that msg'ed us.
-	// since we receive the actual message by readBlock(), we need
+	// since we receive the actual message by read(), we need
 	// to remember what the handle was of the person sending us the message.
 	QString m_msgHandle;
 
@@ -67,15 +69,15 @@ private:
 	QStringList m_chatMembers;
 
 	//used for emoticons
-	QValueList<const Kopete::Message> m_msgQueue;
+	QList<Kopete::Message> m_msgQueue;
 	unsigned  m_recvIcons;
-	QMap<QString , QPair<QString , KTempFile*> >  m_emoticons;
+	QMap<QString , QPair<QString , KTemporaryFile*> >  m_emoticons;
 	Kopete::Message &parseCustomEmoticons(Kopete::Message &msg);
 	QTimer *m_emoticonTimer;
-	QPtrList<KTempFile> m_typewrited;
+	QList<KTemporaryFile*> m_typewrited;
 
 	struct InkMessage{
-		Q_UINT32 chunks;
+		quint32 chunks;
 		QString data;
 	};
 	QMap<QString, InkMessage> m_inkMessageBuffer;
@@ -119,6 +121,10 @@ public:
 
 	P2P::Dispatcher* PeerDispatcher();
 
+    /** workaround Bug 113425 . see slotKeepAliveTimer() **/
+	QTimer *m_keepAlive;
+	int m_keepAliveNb;
+
 public slots:
 	void slotCloseSession();
 	void slotInviteContact(const QString &handle);
@@ -129,19 +135,13 @@ public slots:
 	void sendTypingMsg( bool isTyping );
 
 	void requestDisplayPicture();
-	
-	/** workaround Bug 113425 . see slotKeepAliveTimer() **/
-	QTimer *m_keepAlive;
-	int m_keepAliveNb;
-	
-
 
 private slots:
 	void slotOnlineStatusChanged( MSNSocket::OnlineStatus status );
 	void slotSocketClosed(  );
 	void slotReadMessage( const QByteArray &bytes );
-	void slotEmoticonReceived( KTempFile *, const QString& );
-	void slotIncomingFileTransfer(const QString& from, const QString& fileName, Q_INT64 fileSize);
+	void slotEmoticonReceived( KTemporaryFile *, const QString& );
+	void slotIncomingFileTransfer(const QString& from, const QString& fileName, qint64 fileSize);
 	void cleanQueue();
 	
 	/** workaround Bug 113425 . see comment inside the function **/
