@@ -19,43 +19,56 @@ Kopete (c) 2002-2005 by the Kopete developers <kopete-devel@kde.org>
 #define CONNECTION_H
 
 #include <qobject.h>
-#include <qvaluelist.h>
+#include <QList>
 #include "oscartypes.h"
 #include "rateclass.h"
+#include "liboscar_export.h"
 
 class ConnectionPrivate;
 class Client;
 class ClientStream;
-class Connector;
-class ByteStream;
 class Transfer;
 class RateClassManager;
-class SSIManager;
+class ContactManager;
 class Task;
+class QHostAddress;
 
 
 namespace Oscar
 {
 class Settings;
+
+class MessageInfo
+{
+public:
+	MessageInfo() : id( 0 ) {}
+	bool isValid() const { return (id > 0 && !contact.isEmpty()); }
+
+	uint id;
+	QString contact;
+};
+
 }
 
 /**
+ * @brief a single independent connection to an OSCAR server
+ * 
  * This class encapsulates both the low level network layer code and the high
  * level OSCAR protocol code required to create a single independent
  * connection to an OSCAR server
  * @author Matt Rogers
  */
-class Connection : public QObject
+class LIBOSCAR_EXPORT Connection : public QObject
 {
 Q_OBJECT
 public:
 
-	Connection( Connector* connector, ClientStream* cs, const char* name = 0 );
+	explicit Connection( ClientStream* cs, const char* name = 0 );
 	~Connection();
 
 	void setClient( Client* );
 
-	void connectToServer( const QString& server, bool auth = true );
+	void connectToServer( const QString& host, quint16 port );
 	/**
 	 * Close the connection and reset the connection data
 	 */
@@ -72,14 +85,14 @@ public:
 	 * Get the list of supported families
 	 * @return The list of families supported on this connection
 	 */
-	QValueList<int> supportedFamilies() const;
+	QList<int> supportedFamilies() const;
 
 	/**
 	 * Add the SNAC families in \p familyList to the list of supported families for
 	 * this connection
 	 * \param familyList the list of families to add
 	 */
-	void addToSupportedFamilies( const QValueList<int>& familyList );
+	void addToSupportedFamilies( const QList<int>& familyList );
 
 	/**
 	 * Add the SNAC family in \p family to the list of supported families for
@@ -94,7 +107,7 @@ public:
 	 * need to be filtered on
 	 * \param rateClassList the list of rate classes to add
 	 */
-	void addToRateClasses( const QValueList<RateClass*> rateClassList );
+	void addToRateClasses( const QList<RateClass*> rateClassList );
 
 	/**
 	 * Add the rate class in \p rc to the list of rate classes packets
@@ -108,7 +121,7 @@ public:
 	 * Indicate to the connection that there has been an error in a task. The
 	 * error won't require us to go offline, but the user should be notified
 	 * about the error
-	 * \param s the SNAC the error occured from
+	 * \param s the SNAC the error occurred from
 	 * \param errCode the error code
 	 */
 	void taskError( const Oscar::SNAC& s, int errCode );
@@ -118,24 +131,28 @@ public:
 	 * This error will require a disconnection from the OSCAR service and if
 	 * necessary, the user should be prompted to reconnect manually or an
 	 * automatic reconnection should be attempted.
-	 * \param s the SNAC the error occured from
+	 * \param s the SNAC the error occurred from
 	 * \param errCode the error code
 	 */
 	void fatalTaskError( const Oscar::SNAC& s, int errCode );
 
     /**
      * Get the chat room name for this connection.
-     * @return the name of the room or QString::null if not connected to a room
+     * @return the name of the room or QString() if not connected to a room
      */
 
 	/** Get the user settings object */
 	Oscar::Settings* settings() const;
 
 	/** Get the current FLAP sequence for this connection */
-	Q_UINT16 flapSequence();
+	Oscar::WORD flapSequence();
 
-	/** Get the current SNAC sequence for this connection */
-	Q_UINT32 snacSequence();
+	/** Get the current SNAC sequence for this connection
+	 * @note for historical reasons the internal counter is WORD only as we used it for
+	 * long time as WORD on many places. If should be save to change it to DWORD for our
+	 * Oscar implementation but Oscar protocol could brake especially on higher values.
+	 */
+	Oscar::DWORD snacSequence();
 
 	/** Get the cookie for this connection */
 	QByteArray cookie() const;
@@ -143,20 +160,26 @@ public:
 	QString userId() const;
 	QString password() const;
 	bool isIcq() const;
-	SSIManager* ssiManager() const;
+	ContactManager* ssiManager() const;
 	const Oscar::ClientVersion* version() const;
+	Oscar::Guid versionCap() const;
 	RateClassManager* rateManager() const;
 	bool isLoggedIn() const;
 
+	QHostAddress localAddress() const;
+
+	/** Map snac sequence to message info */
+	void addMessageInfo( Oscar::DWORD snacSequence, const Oscar::MessageInfo& messageInfo );
+
+	/** Return message info for snac sequence and remove it from map */
+	Oscar::MessageInfo takeMessageInfo( Oscar::DWORD snacSequence );
+
+	/** Return message info list */
+	QList<Oscar::MessageInfo> messageInfoList() const;
+
 	/** Convenience function to get the root task for use in Tasks */
 	Task* rootTask() const;
 
-	/** Get the raw connector for this connection, in case we need it */
-	Connector* connector();
-
-	/** Get the byte stream for this connection, in case we need it */
-	ByteStream* byteStream();
-
 	void send( Transfer* t ) const;
 	void forcedSend( Transfer* t ) const;
 
