@@ -102,10 +102,7 @@ void OscarPrivacyEngine::slotAdd()
 	else
 		id = m_comboBox->currentText();
 	
-	QRegExp rxIcq("^[0-9]*$");
-	QRegExp rxAim("^[A-Za-z][@.\\d\\s\\w]{2,15}$");
-	
-	if ( !rxIcq.exactMatch( id ) && !rxAim.exactMatch( id ) || m_idSet.contains( id ) )
+	if ( id.isEmpty() || m_idSet.contains( id ) )
 		return;
 	
 	int rowCount = m_contactsModel.rowCount();
@@ -123,7 +120,7 @@ void OscarPrivacyEngine::slotRemove()
 {
 	QItemSelectionModel *selectionModel = m_listView->selectionModel();
 	
-	foreach ( QModelIndex selectedIndex, selectionModel->selectedIndexes() )
+	foreach ( const QModelIndex &selectedIndex, selectionModel->selectedIndexes() )
 	{
 		QString id = selectedIndex.data( Qt::UserRole ).toString();
 		
@@ -139,8 +136,8 @@ void OscarPrivacyEngine::storeChanges()
 	if ( !m_client->isActive() )
 		return;
 	
-	ChangeMap::Iterator it, cEnd = m_changesMap.end();
-	for ( it = m_changesMap.begin(); it != cEnd; ++it )
+	ChangeMap::ConstIterator it, cEnd = m_changesMap.constEnd();
+	for ( it = m_changesMap.constBegin(); it != cEnd; ++it )
 	{
 		switch( m_type )
 		{
@@ -165,7 +162,7 @@ void OscarPrivacyEngine::addContacts( const ContactMap& contacts, const QSet<QSt
 	m_contactsModel.insertRows( 0, idSet.size() );
 	
 	int i = 0;
-	foreach ( QString id, idSet )
+	foreach ( const QString& id, idSet )
 	{
 		QModelIndex index = m_contactsModel.index( i++, 0 );
 		
