@@ -1,6 +1,6 @@
 /*
  * bytestream.h - base class for bytestreams
- * Copyright (C) 2003  Justin Karneges
+ * Copyright (C) 2003  Justin Karneges <justin@affinix.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -66,7 +66,7 @@ protected:
 private:
 //! \if _hide_doc_
 	class Private;
-	Private *d;
+	Private * const d;
 //! \endif
 };
 // CS_EXPORT_END
