@@ -543,7 +543,8 @@ void YahooAccount::disconnect()
 	if ( isConnected() )
 	{
 		kDebug(YAHOO_GEN_DEBUG) <<  "Attempting to disconnect from Yahoo server ";
-
+		
+		disconnected( Manual );
 		m_session->close();
 		static_cast<YahooContact *>( myself() )->setOnlineStatus( m_protocol->Offline );
 
@@ -551,7 +552,6 @@ void YahooAccount::disconnect()
 		for ( it = contacts().constBegin(); it != itEnd; ++it )
 			static_cast<YahooContact *>( it.value() )->setOnlineStatus( m_protocol->Offline );
 
-		disconnected( Manual );
 	}
 	else
 	{       //make sure we set everybody else offline explicitly, just for cleanup
@@ -1803,7 +1803,7 @@ void YahooAccount::slotWebcamPaused( const QString &who )
 	kc->webcamPaused();
 }
 
-void YahooAccount::setOnlineStatus( const Kopete::OnlineStatus& status , const Kopete::StatusMessage &reason)
+void YahooAccount::setOnlineStatus( const Kopete::OnlineStatus& status, const Kopete::StatusMessage &reason, const OnlineStatusOptions& options )
 {
 	kDebug(YAHOO_GEN_DEBUG) ;
 	if ( myself()->onlineStatus().status() == Kopete::OnlineStatus::Offline &&
