@@ -1,7 +1,7 @@
 /* -*- C++ -*-
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: accounting.h 212185 2003-03-07 22:11:39Z waba $
+ * $Id: accounting.h 704683 2007-08-25 19:55:14Z amth $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -20,14 +20,16 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef __ACCOUNTING__H__
 #define __ACCOUNTING__H__
 
 #include <qobject.h>
-#include <kprocess.h>
+//Added by qt3to4:
+#include <QTimerEvent>
+#include <k3process.h>
 #include "ruleset.h"
 
 class PPPStats;
@@ -46,18 +48,18 @@ public:
   virtual double total() const;
   virtual double session() const;
 
-  virtual bool running() const { return false; };
+  virtual bool running() const { return false; }
   virtual bool loadRuleSet(const QString & name) = 0;
 
 public slots:
-  virtual void slotStart() {};
-  virtual void slotStop() {};
+  virtual void slotStart() {}
+  virtual void slotStop() {}
 
 signals:
   void changed(QString total, QString session);
 
 protected:
-  void logMessage(QString, bool = FALSE);
+  void logMessage(const QString &, bool = false);
   bool saveCosts();
   bool loadCosts();
 
@@ -119,7 +121,7 @@ private:
 class ExecutableAccounting : public AccountingBase {
   Q_OBJECT
 public:
-  ExecutableAccounting(PPPStats *st, QObject *parent = 0);
+  explicit ExecutableAccounting(PPPStats *st, QObject *parent = 0);
 
   virtual bool loadRuleSet(const QString & );
   virtual bool running() const;
@@ -129,13 +131,13 @@ public slots:
   virtual void slotStop();
 
 private slots:
-  void gotData(KProcess *proc, char *buffer, int buflen);
+  void gotData(K3Process *proc, char *buffer, int buflen);
 
 signals:
   void changed(QString total, QString session);
 
 private:
-  KProcess *proc;
+  K3Process *proc;
   QString currency;
   QString provider;
   PPPStats *stats;
