@@ -1,7 +1,7 @@
 /*
  *        kPPP: A pppd front end for the KDE project
  *
- * $Id: debug.cpp 233655 2003-06-25 07:08:43Z deller $
+ * $Id: debug.cpp 725496 2007-10-15 15:07:57Z mlaurent $
  *            Copyright (C) 1997  Bernd Wuebben
  *                 wuebben@math.cornel.edu
  *
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "debug.h"
@@ -26,38 +26,40 @@
 #include <klocale.h>
 
 #include <assert.h>
+//Added by qt3to4:
+#include <QHideEvent>
+#include <QLabel>
+#include <QFrame>
+#include <QResizeEvent>
 
 extern KPPPWidget *p_kppp;
 
 myMultiEdit::myMultiEdit(QWidget *parent, const char *name)
-  : QMultiLineEdit(parent, name)
+  : Q3MultiLineEdit(parent, name)
 {
  setReadOnly(true);
 }
 
-void myMultiEdit::insertChar(unsigned char c) {
-  QMultiLineEdit::insert(QChar(c));
-}
-
-
 void myMultiEdit::newLine() {
-  QMultiLineEdit::newLine();
+  Q3MultiLineEdit::newLine();
 }
 
 
-DebugWidget::DebugWidget(QWidget *parent, const char *name)
-  : QDialog(parent, name, FALSE)
+DebugWidget::DebugWidget(QWidget *parent)
+  : QDialog(parent)
 {
-  setCaption(i18n("Login Script Debug Window"));
+    setModal( false );
+  setWindowTitle(i18n("Login Script Debug Window"));
 
   text_window = new myMultiEdit(this,"debugwindow");
   text_window->setGeometry(2,5,400, 300);
   //  text_window->setReadOnly(FALSE);
 
-  statuslabel = new QLabel("", this, "statuslabel");
+  statuslabel = new QLabel(QString(), this );
+  statuslabel->setObjectName("statuslabel");
 
   statuslabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
-  statuslabel->setAlignment( AlignLeft|AlignVCenter );
+  statuslabel->setAlignment( Qt::AlignLeft|Qt::AlignVCenter );
   statuslabel->setGeometry(2, 307, 400, 20);
   //statusPageLabel->setFont( KGlobalSettings::generalFont() );
 
@@ -79,11 +81,11 @@ DebugWidget::DebugWidget(QWidget *parent, const char *name)
 void DebugWidget::hideEvent(QHideEvent *)
 {
   assert(p_kppp);
-  p_kppp->con->debug->setOn(false);
+  p_kppp->con->debug->setChecked(false);
 }
 
 void DebugWidget::clear() {
-  text_window->clear(); 
+  text_window->clear();
 }
 
 
@@ -92,9 +94,9 @@ void DebugWidget::addChar(unsigned char c) {
 
   if(c == '\r' || c == '\n') {
     if(c == '\n')
-      text_window->newLine();    
+      text_window->newLine();
   } else
-    text_window->insertChar(c);
+    text_window->insert(QString(c));
 }
 
 
