@@ -1,7 +1,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: edit.cpp 386839 2005-02-06 19:13:46Z binner $
+ * $Id: edit.cpp 886322 2008-11-18 23:53:04Z finex $
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
  *
@@ -20,23 +20,26 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <string.h>
 #include <termios.h>
 #include <qlayout.h>
+//Added by qt3to4:
+#include <QGridLayout>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QVBoxLayout>
+#include <QApplication>
 #include <kmessagebox.h>
-#include <qwhatsthis.h>
+
 #include <qregexp.h>
-#include <kapplication.h>
 #include <kiconloader.h>
-#include <kbuttonbox.h>
+#include <kdialogbuttonbox.h>
 #include <klocale.h>
-#include <qvgroupbox.h>
-#include <qhbox.h>
 #include <kdialog.h>
-#include <kwin.h>
+#include <kwindowsystem.h>
 
 #include "edit.h"
 #include "pppdata.h"
@@ -44,46 +47,51 @@
 #include "iplined.h"
 #include "auth.h"
 
-DialWidget::DialWidget( QWidget *parent, bool isnewaccount, const char *name )
-  : QWidget(parent, name)
+DialWidget::DialWidget( QWidget *parent, bool isnewaccount )
+  : QWidget(parent)
 {
-  const int GRIDROWS = 8;
+  parent->setMinimumWidth(440);
+  QVBoxLayout *topLayout = new QVBoxLayout(parent);
+  topLayout->setSpacing(KDialog::spacingHint());
+  topLayout->addWidget(this);
 
-  QGridLayout *tl = new QGridLayout(parent, GRIDROWS, 2, 0, KDialog::spacingHint());
+  QGridLayout *tl = new QGridLayout(this );
+  tl->setSpacing( KDialog::spacingHint() );
 
-  connect_label = new QLabel(i18n("Connection &name:"), parent);
+  connect_label = new QLabel(i18n("Connection &name:"), this);
   tl->addWidget(connect_label, 0, 0);
 
-  connectname_l = new QLineEdit(parent);
+  connectname_l = new QLineEdit(this);
   connectname_l->setMaxLength(ACCNAME_SIZE);
   connect_label->setBuddy(connectname_l);
 
   tl->addWidget(connectname_l, 0, 1);
   QString tmp = i18n("Type in a unique name for this connection");
 
-  QWhatsThis::add(connect_label,tmp);
-  QWhatsThis::add(connectname_l,tmp);
+  connect_label->setWhatsThis(tmp);
+  connectname_l->setWhatsThis(tmp);
 
 
-  number_label = new QLabel(i18n("P&hone number:"), parent);
-  number_label->setAlignment(AlignTop|AlignLeft);
+  number_label = new QLabel(i18n("P&hone number:"), this);
+  number_label->setAlignment(Qt::AlignTop|Qt::AlignLeft);
   tl->addWidget(number_label, 1, 0);
 
-  QHBoxLayout *lpn = new QHBoxLayout(5);
+  QHBoxLayout *lpn = new QHBoxLayout();
+  lpn->setSpacing( 5 );
   tl->addLayout(lpn, 1, 1);
-  numbers = new QListBox(parent);
+  numbers = new Q3ListBox(this);
   number_label->setBuddy(numbers);
   numbers->setMinimumSize(120, 70);
   lpn->addWidget(numbers);
   QVBoxLayout *lpn1 = new QVBoxLayout;
   lpn->addLayout(lpn1);
-  add = new QPushButton(i18n("&Add..."), parent);
-  del = new QPushButton(i18n("&Remove"), parent);
+  add = new QPushButton(i18n("&Add..."), this);
+  del = new QPushButton(i18n("&Remove"), this);
 
-  up = new QPushButton(parent);
-  up->setIconSet(BarIconSet("up"));
-  down = new QPushButton(parent);
-  down->setIconSet(BarIconSet("down"));
+  up = new QPushButton(this);
+  up->setIcon(KIcon("go-up"));
+  down = new QPushButton(this);
+  down->setIcon(KIcon("go-down"));
   lpn1->addWidget(add);
   lpn1->addWidget(del);
   lpn1->addStretch(1);
@@ -109,19 +117,19 @@ DialWidget::DialWidget( QWidget *parent, bool isnewaccount, const char *name )
 	     "When a number is busy or fails, <i>kppp</i> will \n"
 	     "try the next number and so on");
 
-  QWhatsThis::add(number_label,tmp);
-  QWhatsThis::add(numbers,tmp);
+  number_label->setWhatsThis(tmp);
+  numbers->setWhatsThis(tmp);
 
-  auth_l = new QLabel(i18n("A&uthentication:"), parent);
+  auth_l = new QLabel(i18n("A&uthentication:"), this);
   tl->addWidget(auth_l, 3, 0);
 
-  auth = new QComboBox(parent);
+  auth = new QComboBox(this);
   auth_l->setBuddy(auth);
-  auth->insertItem(i18n("Script-based"));
-  auth->insertItem(i18n("PAP"));
-  auth->insertItem(i18n("Terminal-based"));
-  auth->insertItem(i18n("CHAP"));
-  auth->insertItem(i18n("PAP/CHAP"));
+  auth->addItem(i18n("Script-based"));
+  auth->addItem(i18n("PAP"));
+  auth->addItem(i18n("Terminal-based"));
+  auth->addItem(i18n("CHAP"));
+  auth->addItem(i18n("PAP/CHAP"));
   tl->addWidget(auth, 3, 1);
   tmp = i18n("<p>Specifies the method used to identify yourself to\n"
 	     "the PPP server. Most universities still use\n"
@@ -133,13 +141,13 @@ DialWidget::DialWidget( QWidget *parent, bool isnewaccount, const char *name )
 	     "choose CHAP, because it's much safer. If you don't know\n"
 	     "whether PAP or CHAP is right, choose PAP/CHAP.");
 
-  QWhatsThis::add(auth_l,tmp);
-  QWhatsThis::add(auth,tmp);
+  auth_l->setWhatsThis(tmp);
+  auth->setWhatsThis(tmp);
 
-  store_password = new QCheckBox(i18n("Store &password"), parent);
+  store_password = new QCheckBox(i18n("Store &password"), this);
   store_password->setChecked(true);
-  tl->addMultiCellWidget(store_password, 4, 4, 0, 1, AlignRight);
-  QWhatsThis::add(store_password,
+  tl->addWidget(store_password, 4, 0, 1, 2, Qt::AlignRight);
+  store_password->setWhatsThis(
 		  i18n("<p>When this is turned on, your ISP password\n"
 		       "will be saved in <i>kppp</i>'s config file, so\n"
 		       "you do not need to type it in every time.\n"
@@ -149,37 +157,37 @@ DialWidget::DialWidget( QWidget *parent, bool isnewaccount, const char *name )
 		       "readable only to you. Make sure nobody\n"
 		       "gains access to this file!"));
 
-  cbtype_l = new QLabel(i18n("&Callback type:"), parent);
+  cbtype_l = new QLabel(i18n("&Callback type:"), this);
   tl->addWidget(cbtype_l, 5, 0);
 
-  cbtype = new QComboBox(parent);
+  cbtype = new QComboBox(this);
   cbtype_l->setBuddy(cbtype);
-  cbtype->insertItem(i18n("None"));
-  cbtype->insertItem(i18n("Administrator-defined"));
-  cbtype->insertItem(i18n("User-defined"));
+  cbtype->addItem(i18n("None"));
+  cbtype->addItem(i18n("Administrator-defined"));
+  cbtype->addItem(i18n("User-defined"));
   connect(cbtype, SIGNAL(highlighted(int)),
 	  this, SLOT(cbtypeChanged(int)));
   tl->addWidget(cbtype, 5, 1);
   tmp = i18n("Callback type");
 
-  QWhatsThis::add(cbtype_l,tmp);
-  QWhatsThis::add(cbtype,tmp);
+  cbtype_l->setWhatsThis(tmp);
+  cbtype->setWhatsThis(tmp);
 
-  cbphone_l = new QLabel(i18n("Call&back number:"), parent);
+  cbphone_l = new QLabel(i18n("Call&back number:"), this);
   tl->addWidget(cbphone_l, 6, 0);
 
-  cbphone = new QLineEdit(parent);
+  cbphone = new QLineEdit(this);
   cbphone_l->setBuddy(cbphone);
   cbphone->setMaxLength(140);
   tl->addWidget(cbphone, 6, 1);
   tmp = i18n("Callback phone number");
 
-  QWhatsThis::add(cbphone_l,tmp);
-  QWhatsThis::add(cbphone,tmp);
+  cbphone_l->setWhatsThis(tmp);
+  cbphone->setWhatsThis(tmp);
 
-  pppdargs = new QPushButton(i18n("Customize &pppd Arguments..."), parent);
+  pppdargs = new QPushButton(i18n("Customize &pppd Arguments..."), this);
   connect(pppdargs, SIGNAL(clicked()), SLOT(pppdargsbutton()));
-  tl->addMultiCellWidget(pppdargs, 7, 7, 0, 1, AlignCenter);
+  tl->addWidget(pppdargs, 7, 0, 1, 2, Qt::AlignCenter);
 
   // Set defaults if editing an existing connection
   if(!isnewaccount) {
@@ -188,7 +196,7 @@ DialWidget::DialWidget( QWidget *parent, bool isnewaccount, const char *name )
     // insert the phone numbers into the listbox
     QString n = gpppdata.phonenumber();
     QString tmp = "";
-    uint idx = 0;
+    int idx = 0;
     while(idx != n.length()) {
       if(n[idx] == ':') {
 	if(tmp.length() > 0)
@@ -201,18 +209,18 @@ DialWidget::DialWidget( QWidget *parent, bool isnewaccount, const char *name )
     if(tmp.length() > 0)
       numbers->insertItem(tmp);
 
-    auth->setCurrentItem(gpppdata.authMethod());
+    auth->setCurrentIndex(gpppdata.authMethod());
     store_password->setChecked(gpppdata.storePassword());
-    cbtype->setCurrentItem(gpppdata.callbackType());
+    cbtype->setCurrentIndex(gpppdata.callbackType());
     cbphone->setText(gpppdata.callbackPhone());
   } else {
     // select PAP/CHAP as default
-    auth->setCurrentItem(AUTH_PAPCHAP);
+    auth->setCurrentIndex(AUTH_PAPCHAP);
     // select NONE as default
-    cbtype->setCurrentItem(CBTYPE_NONE);
+    cbtype->setCurrentIndex(CBTYPE_NONE);
   }
 
-  emit cbtypeChanged(cbtype->currentItem());
+  emit cbtypeChanged(cbtype->currentIndex());
   numbersChanged();
   tl->activate();
 }
@@ -229,14 +237,14 @@ bool DialWidget::save() {
     QString number = "";
     for(uint i = 0; i < numbers->count(); i++) {
       if(i != 0)
-	number += ":";
+	number += ':';
       number += numbers->text(i);
     }
 
     gpppdata.setPhonenumber(number);
-    gpppdata.setAuthMethod(auth->currentItem());
+    gpppdata.setAuthMethod(auth->currentIndex());
     gpppdata.setStorePassword(store_password->isChecked());
-    gpppdata.setCallbackType(cbtype->currentItem());
+    gpppdata.setCallbackType(cbtype->currentIndex());
     gpppdata.setCallbackPhone(cbphone->text());
     return true;
   }
@@ -312,10 +320,12 @@ void DialWidget::pppdargsbutton() {
 /////////////////////////////////////////////////////////////////////////////
 // ExecWidget
 /////////////////////////////////////////////////////////////////////////////
-ExecWidget::ExecWidget(QWidget *parent, bool isnewaccount, const char *name) :
-  QWidget(parent, name)
+ExecWidget::ExecWidget(QWidget *parent, bool isnewaccount) :
+  QWidget(parent)
 {
-  QVBoxLayout *tl = new QVBoxLayout(parent, 0, KDialog::spacingHint());
+  QVBoxLayout *tl = new QVBoxLayout(parent);
+  tl->setSpacing(KDialog::spacingHint());
+  tl->setMargin(0);
 
   QLabel *l = new QLabel(\
 i18n("Here you can select commands to run at certain stages of the\n"
@@ -328,13 +338,14 @@ i18n("Here you can select commands to run at certain stages of the\n"
   tl->addWidget(l);
   tl->addStretch(1);
 
-  QGridLayout *l1 = new QGridLayout(4, 2, 10);
+  QGridLayout *l1 = new QGridLayout( );
+  l1->setMargin( 10 );
   tl->addLayout(l1);
-  l1->setColStretch(0, 0);
-  l1->setColStretch(1, 1);
+  l1->setColumnStretch(0, 0);
+  l1->setColumnStretch(1, 1);
 
   before_connect_l = new QLabel(i18n("&Before connect:"), parent);
-  before_connect_l->setAlignment(AlignVCenter);
+  before_connect_l->setAlignment(Qt::AlignVCenter);
   l1->addWidget(before_connect_l, 0, 0);
   before_connect = new QLineEdit(parent);
   before_connect_l->setBuddy(before_connect);
@@ -346,11 +357,11 @@ i18n("Here you can select commands to run at certain stages of the\n"
 	     "This might be useful, e.g. to stop HylaFAX blocking the\n"
 	     "modem.");
 
-  QWhatsThis::add(before_connect_l,tmp);
-  QWhatsThis::add(before_connect,tmp);
+  before_connect_l->setWhatsThis(tmp);
+  before_connect->setWhatsThis(tmp);
 
   command_label = new QLabel(i18n("&Upon connect:"), parent);
-  command_label->setAlignment(AlignVCenter);
+  command_label->setAlignment(Qt::AlignVCenter);
   l1->addWidget(command_label, 1, 0);
   command = new QLineEdit(parent);
   command_label->setBuddy(command);
@@ -362,12 +373,12 @@ i18n("Here you can select commands to run at certain stages of the\n"
 	     "\n"
 	     "Very useful for fetching mail and news");
 
-  QWhatsThis::add(command_label,tmp);
-  QWhatsThis::add(command,tmp);
+  command_label->setWhatsThis(tmp);
+  command->setWhatsThis(tmp);
 
   predisconnect_label = new QLabel(i18n("Before &disconnect:"),
 				 parent);
-  predisconnect_label->setAlignment(AlignVCenter);
+  predisconnect_label->setAlignment(Qt::AlignVCenter);
   l1->addWidget(predisconnect_label, 2, 0);
   predisconnect = new QLineEdit(parent);
   predisconnect_label->setBuddy(predisconnect);
@@ -377,12 +388,12 @@ i18n("Here you can select commands to run at certain stages of the\n"
 	     "is closed. The connection will stay open until\n"
 	     "the program exits.");
 
-  QWhatsThis::add(predisconnect_label,tmp);
-  QWhatsThis::add(predisconnect,tmp);
+  predisconnect_label->setWhatsThis(tmp);
+  predisconnect->setWhatsThis(tmp);
 
   discommand_label = new QLabel(i18n("U&pon disconnect:"),
 			      parent);
-  discommand_label->setAlignment(AlignVCenter);
+  discommand_label->setAlignment(Qt::AlignVCenter);
   l1->addWidget(discommand_label, 3, 0);
 
   discommand = new QLineEdit(parent);
@@ -392,12 +403,12 @@ i18n("Here you can select commands to run at certain stages of the\n"
   tmp = i18n("Allows you to run a program <b>after</b> a connection\n"
 	     "has been closed.");
 
-  QWhatsThis::add(discommand_label,tmp);
-  QWhatsThis::add(discommand,tmp);
+  discommand_label->setWhatsThis(tmp);
+  discommand->setWhatsThis(tmp);
 
   // extra space between entries
-  l1->addRowSpacing(1, 5);
-  l1->addRowSpacing(3, 5);
+  l1->addItem(new QSpacerItem(0, 5), 1, 0);
+  l1->addItem(new QSpacerItem(0, 5), 3, 0);
 
   tl->addStretch(1);
   tl->activate();
@@ -428,22 +439,23 @@ bool ExecWidget::save() {
 //
 /////////////////////////////////////////////////////////////////////////////
 IPWidget::IPWidget( QWidget *parent, bool isnewaccount, const char *name )
-  : QWidget(parent, name)
+  : QWidget(parent)
 {
+  setObjectName(name);
   QVBoxLayout *topLayout = new QVBoxLayout(parent);
   topLayout->setSpacing(KDialog::spacingHint());
 
-  box = new QVGroupBox(i18n("C&onfiguration"), parent);
+  box = new Q3GroupBox(1, Qt::Horizontal,i18n("C&onfiguration"), parent);
   box->setInsideSpacing(KDialog::spacingHint());
 
-  rb = new QButtonGroup(parent);
+  rb = new Q3ButtonGroup(parent);
   rb->hide();
   connect(rb, SIGNAL(clicked(int)),
 	  SLOT(hitIPSelect(int)));
 
   dynamicadd_rb = new QRadioButton(box);
   dynamicadd_rb->setText(i18n("Dynamic IP address"));
-  QWhatsThis::add(dynamicadd_rb,
+  dynamicadd_rb->setWhatsThis(
 		  i18n("Select this option when your computer gets an\n"
 		       "internet address (IP) every time a\n"
 		       "connection is made.\n"
@@ -455,7 +467,7 @@ IPWidget::IPWidget( QWidget *parent, bool isnewaccount, const char *name )
   staticadd_rb->setText(i18n("Static IP address"));
   rb->insert(dynamicadd_rb, 0);
   rb->insert(staticadd_rb, 1);
-  QWhatsThis::add(staticadd_rb,
+  staticadd_rb->setWhatsThis(
 		  i18n("Select this option when your computer has a\n"
 		       "fixed internet address (IP). Most computers\n"
 		       "don't have this, so you should probably select\n"
@@ -463,7 +475,7 @@ IPWidget::IPWidget( QWidget *parent, bool isnewaccount, const char *name )
 		       "are doing."));
 
   QWidget *ipWidget = new QWidget(box);
-  QGridLayout *ipLayout = new QGridLayout(ipWidget, 2, 2);
+  QGridLayout *ipLayout = new QGridLayout(ipWidget);
   ipLayout->setSpacing(KDialog::spacingHint());
 
   ipaddress_label = new QLabel(i18n("&IP address:"), ipWidget);
@@ -475,8 +487,8 @@ IPWidget::IPWidget( QWidget *parent, bool isnewaccount, const char *name )
   ipaddress_label->setBuddy(ipaddress_l);
   ipLayout->addWidget(ipaddress_l, 0, 1);
 
-  QWhatsThis::add(ipaddress_label,tmp);
-  QWhatsThis::add(ipaddress_l,tmp);
+  ipaddress_label->setWhatsThis(tmp);
+  ipaddress_l->setWhatsThis(tmp);
 
   sub_label = new QLabel(i18n("&Subnet mask:"), ipWidget);
   tmp = i18n("<p>If your computer has a static Internet address,\n"
@@ -491,15 +503,15 @@ IPWidget::IPWidget( QWidget *parent, bool isnewaccount, const char *name )
   sub_label->setBuddy(subnetmask_l);
   ipLayout->addWidget(subnetmask_l, 1, 1);
 
-  QWhatsThis::add(sub_label,tmp);
-  QWhatsThis::add(subnetmask_l,tmp);
+  sub_label->setWhatsThis(tmp);
+  subnetmask_l->setWhatsThis(tmp);
 
   autoname = new QCheckBox(i18n("&Auto-configure hostname from this IP"), parent);
   autoname->setChecked(gpppdata.autoname());
   connect(autoname,SIGNAL(toggled(bool)),
 	  this,SLOT(autoname_t(bool)));
 
-  QWhatsThis::add(autoname,
+  autoname->setWhatsThis(
 		  i18n("<p>Whenever you connect, this reconfigures\n"
 		       "your hostname to match the IP address you\n"
 		       "got from the PPP server. This may be useful\n"
@@ -583,16 +595,21 @@ void IPWidget::hitIPSelect( int i ) {
 
 
 
-DNSWidget::DNSWidget( QWidget *parent, bool isnewaccount, const char *name )
-  : QWidget(parent, name)
+DNSWidget::DNSWidget( QWidget *parent, bool isnewaccount )
+  : QWidget(parent)
 {
-  //  box = new QGroupBox(parent);
-  QGridLayout *tl = new QGridLayout(parent, 7, 2, 0, KDialog::spacingHint());
+  QVBoxLayout *topLayout = new QVBoxLayout(parent);
+  topLayout->setSpacing(KDialog::spacingHint());
+  topLayout->addWidget(this);
 
-  dnsdomain_label = new QLabel(i18n("Domain &name:"), parent);
+  //  box = new QGroupBox(this);
+  QGridLayout *tl = new QGridLayout(this );
+  tl->setSpacing( KDialog::spacingHint() );
+
+  dnsdomain_label = new QLabel(i18n("Domain &name:"), this);
   tl->addWidget(dnsdomain_label, 0, 0);
 
-  dnsdomain = new QLineEdit(parent);
+  dnsdomain = new QLineEdit(this);
   dnsdomain_label->setBuddy(dnsdomain);
   dnsdomain->setMaxLength(DOMAIN_SIZE);
   tl->addWidget(dnsdomain, 0, 1);
@@ -605,34 +622,34 @@ DNSWidget::DNSWidget( QWidget *parent, bool isnewaccount, const char *name )
 		     "If you leave this field blank, no changes are\n"
 		     "made to the domain name.");
 
-  QWhatsThis::add(dnsdomain_label,tmp);
-  QWhatsThis::add(dnsdomain,tmp);
+  dnsdomain_label->setWhatsThis(tmp);
+  dnsdomain->setWhatsThis(tmp);
 
-  conf_label = new QLabel(i18n("C&onfiguration:"), parent);
+  conf_label = new QLabel(i18n("C&onfiguration:"), this);
   tl->addWidget(conf_label, 1, 0);
 
-  bg = new QButtonGroup("Group", this);
+  bg = new Q3ButtonGroup("Group", this);
   conf_label->setBuddy(bg);
   connect(bg, SIGNAL(clicked(int)), SLOT(DNS_Mode_Selected(int)));
   bg->hide();
 
-  autodns = new QRadioButton(i18n("Automatic"), parent);
+  autodns = new QRadioButton(i18n("Automatic"), this);
   bg->insert(autodns, 0);
   tl->addWidget(autodns, 1, 1);
   // no automatic DNS detection for pppd < 2.3.7
   if(!gpppdata.pppdVersionMin(2, 3, 7))
     autodns->setEnabled(false);
 
-  mandns = new QRadioButton(i18n("Manual"), parent);
+  mandns = new QRadioButton(i18n("Manual"), this);
   bg->insert(mandns, 1);
   tl->addWidget(mandns, 2, 1);
 
-  dns_label = new QLabel(i18n("DNS &IP address:"), parent);
+  dns_label = new QLabel(i18n("DNS &IP address:"), this);
   tl->addWidget(dns_label, 3, 0);
 
   QHBoxLayout *l2 = new QHBoxLayout;
   tl->addLayout(l2, 3, 1);
-  dnsipaddr = new IPLineEdit(parent);
+  dnsipaddr = new IPLineEdit(this);
   dns_label->setBuddy(dnsipaddr);
   connect(dnsipaddr, SIGNAL(returnPressed()),
 	  SLOT(adddns()));
@@ -648,38 +665,38 @@ DNSWidget::DNSWidget( QWidget *parent, bool isnewaccount, const char *name )
 	     "To add a DNS server, type in the IP address of\n"
 	     "the DNS server here and click on <b>Add</b>");
 
-  QWhatsThis::add(dns_label, tmp);
-  QWhatsThis::add(dnsipaddr, tmp);
+  dns_label->setWhatsThis( tmp);
+  dnsipaddr->setWhatsThis( tmp);
 
   QHBoxLayout *l1 = new QHBoxLayout;
   tl->addLayout(l1, 4, 1);
-  add = new QPushButton(i18n("&Add"), parent);
+  add = new QPushButton(i18n("&Add"), this);
   connect(add, SIGNAL(clicked()), SLOT(adddns()));
   int width = add->sizeHint().width();
-  width = QMAX(width,60);
+  width = qMax(width,60);
   add->setMinimumWidth(width);
   l1->addWidget(add);
   l1->addStretch(1);
-  QWhatsThis::add(add,
+  add->setWhatsThis(
 		  i18n("Click this button to add the DNS server\n"
 		       "specified in the field above. The entry\n"
 		       "will then be added to the list below"));
 
-  remove = new QPushButton(i18n("&Remove"), parent);
+  remove = new QPushButton(i18n("&Remove"), this);
   connect(remove, SIGNAL(clicked()), SLOT(removedns()));
   width = remove->sizeHint().width();
-  width = QMAX(width,60);
+  width = qMax(width,60);
   remove->setMinimumWidth(width);
   l1->addWidget(remove);
-  QWhatsThis::add(remove,
+  remove->setWhatsThis(
 		  i18n("Click this button to remove the selected DNS\n"
 		       "server entry from the list below"));
 
-  servers_label = new QLabel(i18n("DNS address &list:"), parent);
-  servers_label->setAlignment(AlignTop|AlignLeft);
+  servers_label = new QLabel(i18n("DNS address &list:"), this);
+  servers_label->setAlignment(Qt::AlignTop|Qt::AlignLeft);
   tl->addWidget(servers_label, 5, 0);
 
-  dnsservers = new QListBox(parent);
+  dnsservers = new Q3ListBox(this);
   servers_label->setBuddy(dnsservers);
   dnsservers->setMinimumSize(150, 80);
   connect(dnsservers, SIGNAL(highlighted(int)),
@@ -689,15 +706,15 @@ DNSWidget::DNSWidget( QWidget *parent, bool isnewaccount, const char *name )
 	     "while you are connected. Use the <b>Add</b> and\n"
 	     "<b>Remove</b> buttons to modify the list");
 
-  QWhatsThis::add(servers_label,tmp);
-  QWhatsThis::add(dnsservers,tmp);
+  servers_label->setWhatsThis(tmp);
+  dnsservers->setWhatsThis(tmp);
 
   exdnsdisabled_toggle = new QCheckBox(i18n( \
 "&Disable existing DNS servers during connection"),
-				     parent);
+				     this);
   exdnsdisabled_toggle->setChecked(gpppdata.exDNSDisabled());
-  tl->addMultiCellWidget(exdnsdisabled_toggle, 6, 6, 0, 1, AlignCenter);
-  QWhatsThis::add(exdnsdisabled_toggle,
+  tl->addWidget(exdnsdisabled_toggle, 6, 0, 1, 2, Qt::AlignCenter);
+  exdnsdisabled_toggle->setWhatsThis(
 		  i18n("<p>When this option is selected, all DNS\n"
 		       "servers specified in <tt>/etc/resolv.conf</tt> are\n"
 		       "temporary disabled while the dialup connection\n"
@@ -724,7 +741,7 @@ DNSWidget::DNSWidget( QWidget *parent, bool isnewaccount, const char *name )
 
 void DNSWidget::DNS_Edit_Changed(const QString &text) {
   QRegExp r("[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]+");
-  add->setEnabled(text.find(r) != -1);
+  add->setEnabled(text.contains(r));
 }
 
 void DNSWidget::DNS_Entry_Selected(int) {
@@ -782,23 +799,23 @@ void DNSWidget::removedns() {
 //
 // GatewayWidget
 //
-GatewayWidget::GatewayWidget( QWidget *parent, bool isnewaccount, const char *name )
-  : QWidget(parent, name)
+GatewayWidget::GatewayWidget( QWidget *parent, bool isnewaccount )
+  : QWidget(parent)
 {
   QVBoxLayout *topLayout = new QVBoxLayout(parent);
   topLayout->setSpacing(KDialog::spacingHint());
 
-  box = new QVGroupBox(i18n("C&onfiguration"), parent);
+  box = new Q3GroupBox (1, Qt::Horizontal,i18n("C&onfiguration"), parent);
   box->setInsideSpacing(KDialog::spacingHint());
 
-  rb = new QButtonGroup(parent);
+  rb = new Q3ButtonGroup(parent);
   rb->hide();
   connect(rb, SIGNAL(clicked(int)), SLOT(hitGatewaySelect(int)));
 
   defaultgateway = new QRadioButton(box);
   defaultgateway->setText(i18n("Default gateway"));
   rb->insert(defaultgateway, 0);
-  QWhatsThis::add(defaultgateway,
+  defaultgateway->setWhatsThis(
 		  i18n("This makes the PPP peer computer (the computer\n"
 		       "you are connected to with your modem) to act as\n"
 		       "a gateway. Your computer will send all packets not\n"
@@ -812,18 +829,21 @@ GatewayWidget::GatewayWidget( QWidget *parent, bool isnewaccount, const char *na
   staticgateway = new QRadioButton(box);
   staticgateway->setText(i18n("Static gateway"));
   rb->insert(staticgateway, 1);
-  QWhatsThis::add(staticgateway,
+  staticgateway->setWhatsThis(
 		  i18n("<p>Allows you to specify which computer you want\n"
 		       "to use as gateway (see <i>Default Gateway</i> above)"));
 
-  QHBox *gateBox = new QHBox(box);
+  QWidget *gateBox = new QWidget(box);
+  QHBoxLayout *hboxLayout1 = new QHBoxLayout(gateBox);
   gate_label = new QLabel(i18n("Gateway &IP address:"), gateBox);
+  hboxLayout1->addWidget(gate_label);
   gatewayaddr = new IPLineEdit(gateBox);
+  hboxLayout1->addWidget(gatewayaddr);
   gate_label->setBuddy(gatewayaddr);
 
   defaultroute = new QCheckBox(i18n("&Assign the default route to this gateway"),
 			     parent);
-  QWhatsThis::add(defaultroute,
+  defaultroute->setWhatsThis(
 		  i18n("If this option is enabled, all packets not\n"
 		       "going to the local net are routed through\n"
 		       "the PPP connection.\n"
@@ -875,35 +895,35 @@ void GatewayWidget::hitGatewaySelect( int i ) {
 
 
 ScriptWidget::ScriptWidget( QWidget *parent, bool isnewaccount, const char *name )
-  : QWidget(parent, name)
+  : QWidget(parent)
 {
-  QVBoxLayout *tl = new QVBoxLayout(parent, 0, KDialog::spacingHint());
+  setObjectName(name);
+  QVBoxLayout *tl = new QVBoxLayout(parent);
+  tl->setSpacing(KDialog::spacingHint());
+  tl->setMargin(0);
   se = new ScriptEdit(parent);
   connect(se, SIGNAL(returnPressed()), SLOT(addButton()));
   tl->addWidget(se);
 
   // insert equal-sized buttons
-  KButtonBox *bbox = new KButtonBox(parent);
-  add = bbox->addButton(i18n("&Add"));
+  KDialogButtonBox *bbox = new KDialogButtonBox(parent);
+  add = bbox->addButton(i18n("&Add"),QDialogButtonBox::ActionRole);
   connect(add, SIGNAL(clicked()), SLOT(addButton()));
-  bbox->addStretch(1);
-  insert = bbox->addButton(i18n("&Insert"));
+  insert = bbox->addButton(i18n("&Insert"),QDialogButtonBox::ActionRole);
   connect(insert, SIGNAL(clicked()), SLOT(insertButton()));
-  bbox->addStretch(1);
-  remove = bbox->addButton(i18n("&Remove"));
+  remove = bbox->addButton(i18n("&Remove"),QDialogButtonBox::ActionRole);
   connect(remove, SIGNAL(clicked()), SLOT(removeButton()));
-  bbox->layout();
   tl->addWidget(bbox);
 
-  QHBoxLayout *l12 = new QHBoxLayout(0);
+  QHBoxLayout *l12 = new QHBoxLayout;
   tl->addLayout(l12);
-  stl = new QListBox(parent);
-  stl->setVScrollBarMode( QScrollView::AlwaysOff );
+  stl = new Q3ListBox(parent);
+  stl->setVScrollBarMode( Q3ScrollView::AlwaysOff );
   connect(stl, SIGNAL(highlighted(int)), SLOT(stlhighlighted(int)));
   stl->setMinimumSize(QSize(70, 140));
 
-  sl = new QListBox(parent);
-  sl->setVScrollBarMode( QScrollView::AlwaysOff );
+  sl = new Q3ListBox(parent);
+  sl->setVScrollBarMode( Q3ScrollView::AlwaysOff );
   connect(sl, SIGNAL(highlighted(int)), SLOT(slhighlighted(int)));
   sl->setMinimumSize(QSize(150, 140));
 
@@ -1086,7 +1106,7 @@ void ScriptWidget::addButton() {
   //get the scrollbar adjusted, and scroll the list so we can see what
   //we're adding to
   adjustScrollBar();
-  slb->setValue(slb->maxValue());
+  slb->setValue(slb->maximum());
 
   //clear the text in the entry box
   se->setText("");
@@ -1201,18 +1221,27 @@ void ScriptWidget::removeButton() {
 // Used to specify a new phone number
 //
 /////////////////////////////////////////////////////////////////////////////
-PhoneNumberDialog::PhoneNumberDialog(QWidget *parent) : KDialogBase(parent, 0, true, i18n("Add Phone Number"), Ok|Cancel) {
-  KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
+PhoneNumberDialog::PhoneNumberDialog(QWidget *parent)
+    : KDialog(parent) {
+    setCaption( i18n("Add Phone Number") );
+    setButtons( Ok|Cancel );
+    setDefaultButton( Ok );
+    setModal( true );
+  KWindowSystem::setIcons(winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)), qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small)));
 
-  QHBox *hbox = new QHBox(this);
+  QWidget *hbox = new QWidget(this);
+  QHBoxLayout *hboxLayout2 = new QHBoxLayout(hbox);
+  hbox->setLayout(hboxLayout2);
   setMainWidget(hbox);
 
-  hbox->setSpacing(KDialog::spacingHint());
+  hboxLayout2->setSpacing(KDialog::spacingHint());
+  
+  QLabel *lbl_le = new QLabel(i18n("Enter a phone number:"));
+  hboxLayout2->addWidget(lbl_le);
 
-  new QLabel(i18n("Enter a phone number:"), hbox);
-
-  le = newLineEdit(14, hbox);
+  QLineEdit *le = new QLineEdit;
   le->setMinimumWidth(125);
+  hboxLayout2->addWidget(le);
 
   connect(le, SIGNAL(textChanged(const QString &)),
 	  this, SLOT(textChanged(const QString &)));
@@ -1220,7 +1249,7 @@ PhoneNumberDialog::PhoneNumberDialog(QWidget *parent) : KDialogBase(parent, 0, t
   le->setFocus();
   textChanged("");
 
-  enableButtonSeparator(true);
+  showButtonSeparator(true);
 }
 
 
@@ -1232,7 +1261,7 @@ QString PhoneNumberDialog::phoneNumber() {
 
 
 void PhoneNumberDialog::textChanged(const QString &s) {
-  enableButtonOK(s.length() > 0);
+  enableButtonOk(s.length() > 0);
 }
 
 
