@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: iplined.cpp 212185 2003-03-07 22:11:39Z waba $
+ * $Id: iplined.cpp 471995 2005-10-19 13:33:01Z mlaurent $
  * 
  *            Copyright (C) 1997 Bernd Johannes Wuebben 
  *                   wuebben@math.cornell.edu
@@ -21,14 +21,16 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "iplined.h"
 
 IPLineEdit::IPLineEdit( QWidget *parent, const char *name )
-  : KRestrictedLine(parent, name, "0123456789.")
+  : KRestrictedLine(parent)
 {
+  setValidChars(QString("0123456789."));
+  setObjectName(name);
   setMaxLength(3 * 4 + 1 * 3);
 }
 
