@@ -3,7 +3,7 @@
  *
  *            kPPP: A front end for pppd for the KDE project
  *
- * $Id: modemcmds.h,v 1.17 2003/07/15 23:54:25 porten Exp $
+ * $Id: modemcmds.h 704675 2007-08-25 19:03:00Z amth $
  *
  * Copyright (C) 1997 Bernd Johannes Wuebben
  * wuebben@math.cornell.edu
@@ -23,7 +23,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -31,8 +31,8 @@
 #ifndef _MODEMCMDS_H_
 #define _MODEMCMDS_H_
 
-#include <qgroupbox.h>
-#include <kdialogbase.h>
+#include <q3groupbox.h>
+#include <kdialog.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
@@ -40,16 +40,15 @@
 
 class QLineEdit;
 class QLabel;
-class QPushButton;
-class QGroupBox;
+class Q3GroupBox;
 
-class ModemCommands : public KDialogBase {
+class ModemCommands : public KDialog {
 
 Q_OBJECT
 
 public:
 
-  ModemCommands(QWidget *parent=0, const char *name=0);
+  explicit ModemCommands(QWidget *parent=0, const char *name=0);
   ~ModemCommands() {}
 
 private slots:
@@ -58,19 +57,22 @@ private slots:
 
 private:
 
-  QGroupBox *box;
+  Q3GroupBox *box;
 
   QLineEdit *initstr[int(PPPData::NumInitStrings)];
 
   QLineEdit *initresp;
   QLabel *label2;
 
+  QSlider *preinitslider;
   QLabel *lpreinitslider;
   QLabel *lpreinit;
 
+  QSlider *initslider;
   QLabel *linitslider;
   QLabel *label3;
 
+  QSlider *durationslider;
   QLabel *ldurationslider;
   QLabel *lduration;
 
@@ -116,6 +118,7 @@ private:
 
   QLabel *label15;
 
+  QSlider *slider;
   QLabel *lslider;
   QLabel *label16;
 
